/**
 * A comment is a user-generated message in response to a specific resource. It allows site visitors
 * to share feedback or engage in discussions around different types of resources, including blog posts, forum threads,
 * or other site content. Comments are composed of text, images, videos, or other forms of media.
 */
interface Comment {
    /**
     * Comment ID.
     * @format GUID
     * @readonly
     */
    _id?: string | null;
    /**
     * Revision number, which increments by 1 each time the comment is updated.
     *
     * To prevent conflicting changes, the current `revision` must be passed when updating the comment.
     * @readonly
     */
    revision?: string | null;
    /**
     * Date and time the comment was created.
     *
     * **Note:** This is the date from the system database, not the actual date when the comment was created. For example, if you migrate comments created in 2016, the `createdDate` field will show the current year. For the actual creation date, see the `commentDate` field.
     * @readonly
     */
    _createdDate?: Date | null;
    /**
     * Date and time the comment was last updated.
     * @readonly
     */
    _updatedDate?: Date | null;
    /**
     * ID of the app that the comment is added to.
     * @format GUID
     * @immutable
     */
    appId?: string | null;
    /**
     * ID of the specific context the comment is in response to.
     *
     * Within some Wix apps, the `contextId` will be the same as the `resourceId`. For example in Wix Forum,
     * the `forumPostId` is used as both the `contextId` and the `resourceId`.
     * @immutable
     * @maxLength 128
     */
    contextId?: string | null;
    /**
     * ID of the specific resource that the comment is in response to.
     *
     * Within some Wix apps, the `resourceId` will be the same as the `contextId`. For example in Wix Forum,
     * the `forumPostId` is used as both the `resourceId` and the `contextId`.
     * @immutable
     * @maxLength 128
     */
    resourceId?: string | null;
    /** Published comment content. */
    content?: CommentContent;
    /**
     * Comment's author.
     * @immutable
     */
    author?: CommentAuthor;
    /**
     * Parent comment information.
     *
     * Only present if this comment is in a direct reply to another comment.
     * See **Terminology** in the Comments introduction
     * for more information about parent comments.
     */
    parentComment?: ParentComment;
    /**
     * Number of comments that reply to this comment.
     * @readonly
     */
    replyCount?: number;
    /**
     * Summary of votes.
     * @readonly
     */
    voteSummary?: VoteSummary;
    /**
     * Comment status.
     * @readonly
     */
    status?: StatusWithLiterals;
    /**
     * Comment rating.
     * @readonly
     */
    rating?: number | null;
    /**
     * Summary of reactions.
     * @readonly
     */
    reactionSummary?: CommentReactionSummary;
    /** Whether the comment is marked. */
    marked?: boolean;
    /**
     * Date and time when the comment was actually created.
     * @immutable
     */
    commentDate?: Date | null;
    /**
     * Whether the comment has the updated content.
     * @readonly
     */
    contentEdited?: boolean | null;
}
/** Comment content. */
interface CommentContent {
    /**
     * Comment rich content.
     *
     * <widget src="https://apps.wix.com/_serverless/ricos-playground-services/goto/api-component" exampleid="5693ba57-d141-42bf-a0d6-1eb11c73bddf" plugins="emoji.heading.indent.lineSpacing.actionButton.audio.codeBlock.collapsibleList.divider.file.gallery.giphy.hashtag.html.image.link.linkButton.linkPreview.mentions.poll.spoiler.table.textColor.textHighlight.verticalEmbed.video">
     * <a href="https://dev.wix.com/docs/ricos/api-reference/ricos-document">See Ricos document reference</a>
     * </widget>
     */
    richContent?: RichContent;
    /**
     * People to tag with this comment.
     *
     * People can include users, members, visitors, or groups.
     * @maxSize 10
     */
    mentions?: Mention[];
    /**
     * Content attachments.
     * @maxSize 10
     */
    attachments?: Attachment[];
}
interface RichContent {
    /** Node objects representing a rich content document. */
    nodes?: Node[];
    /** Object metadata. */
    metadata?: Metadata;
    /** Global styling for header, paragraph, block quote, and code block nodes in the object. */
    documentStyle?: DocumentStyle;
}
interface Node extends NodeDataOneOf {
    /** Data for a button node. */
    buttonData?: ButtonData;
    /** Data for a code block node. */
    codeBlockData?: CodeBlockData;
    /** Data for a divider node. */
    dividerData?: DividerData;
    /** Data for a file node. */
    fileData?: FileData;
    /** Data for a gallery node. */
    galleryData?: GalleryData;
    /** Data for a GIF node. */
    gifData?: GIFData;
    /** Data for a heading node. */
    headingData?: HeadingData;
    /** Data for an embedded HTML node. */
    htmlData?: HTMLData;
    /** Data for an image node. */
    imageData?: ImageData;
    /** Data for a link preview node. */
    linkPreviewData?: LinkPreviewData;
    /** @deprecated */
    mapData?: MapData;
    /** Data for a paragraph node. */
    paragraphData?: ParagraphData;
    /** Data for a poll node. */
    pollData?: PollData;
    /** Data for a text node. Used to apply decorations to text. */
    textData?: TextData;
    /** Data for an app embed node. */
    appEmbedData?: AppEmbedData;
    /** Data for a video node. */
    videoData?: VideoData;
    /** Data for an oEmbed node. */
    embedData?: EmbedData;
    /** Data for a collapsible list node. */
    collapsibleListData?: CollapsibleListData;
    /** Data for a table node. */
    tableData?: TableData;
    /** Data for a table cell node. */
    tableCellData?: TableCellData;
    /** Data for a custom external node. */
    externalData?: Record<string, any> | null;
    /** Data for an audio node. */
    audioData?: AudioData;
    /** Data for an ordered list node. */
    orderedListData?: OrderedListData;
    /** Data for a bulleted list node. */
    bulletedListData?: BulletedListData;
    /** Data for a block quote node. */
    blockquoteData?: BlockquoteData;
    /** Data for a caption node. */
    captionData?: CaptionData;
    /** LayoutData layout_data = 31; // Data for a layout node. Reserved for future use. */
    layoutCellData?: LayoutCellData;
    /** Node type. Use `APP_EMBED` for nodes that embed content from other Wix apps. Use `EMBED` to embed content in [oEmbed](https://oembed.com/) format. */
    type?: NodeTypeWithLiterals;
    /** Node ID. */
    id?: string;
    /** A list of child nodes. */
    nodes?: Node[];
    /** Padding and background color styling for the node. */
    style?: NodeStyle;
}
/** @oneof */
interface NodeDataOneOf {
    /** Data for a button node. */
    buttonData?: ButtonData;
    /** Data for a code block node. */
    codeBlockData?: CodeBlockData;
    /** Data for a divider node. */
    dividerData?: DividerData;
    /** Data for a file node. */
    fileData?: FileData;
    /** Data for a gallery node. */
    galleryData?: GalleryData;
    /** Data for a GIF node. */
    gifData?: GIFData;
    /** Data for a heading node. */
    headingData?: HeadingData;
    /** Data for an embedded HTML node. */
    htmlData?: HTMLData;
    /** Data for an image node. */
    imageData?: ImageData;
    /** Data for a link preview node. */
    linkPreviewData?: LinkPreviewData;
    /** @deprecated */
    mapData?: MapData;
    /** Data for a paragraph node. */
    paragraphData?: ParagraphData;
    /** Data for a poll node. */
    pollData?: PollData;
    /** Data for a text node. Used to apply decorations to text. */
    textData?: TextData;
    /** Data for an app embed node. */
    appEmbedData?: AppEmbedData;
    /** Data for a video node. */
    videoData?: VideoData;
    /** Data for an oEmbed node. */
    embedData?: EmbedData;
    /** Data for a collapsible list node. */
    collapsibleListData?: CollapsibleListData;
    /** Data for a table node. */
    tableData?: TableData;
    /** Data for a table cell node. */
    tableCellData?: TableCellData;
    /** Data for a custom external node. */
    externalData?: Record<string, any> | null;
    /** Data for an audio node. */
    audioData?: AudioData;
    /** Data for an ordered list node. */
    orderedListData?: OrderedListData;
    /** Data for a bulleted list node. */
    bulletedListData?: BulletedListData;
    /** Data for a block quote node. */
    blockquoteData?: BlockquoteData;
    /** Data for a caption node. */
    captionData?: CaptionData;
    /** LayoutData layout_data = 31; // Data for a layout node. Reserved for future use. */
    layoutCellData?: LayoutCellData;
}
declare enum NodeType {
    PARAGRAPH = "PARAGRAPH",
    TEXT = "TEXT",
    HEADING = "HEADING",
    BULLETED_LIST = "BULLETED_LIST",
    ORDERED_LIST = "ORDERED_LIST",
    LIST_ITEM = "LIST_ITEM",
    BLOCKQUOTE = "BLOCKQUOTE",
    CODE_BLOCK = "CODE_BLOCK",
    VIDEO = "VIDEO",
    DIVIDER = "DIVIDER",
    FILE = "FILE",
    GALLERY = "GALLERY",
    GIF = "GIF",
    HTML = "HTML",
    IMAGE = "IMAGE",
    LINK_PREVIEW = "LINK_PREVIEW",
    /** @deprecated */
    MAP = "MAP",
    POLL = "POLL",
    APP_EMBED = "APP_EMBED",
    BUTTON = "BUTTON",
    COLLAPSIBLE_LIST = "COLLAPSIBLE_LIST",
    TABLE = "TABLE",
    EMBED = "EMBED",
    COLLAPSIBLE_ITEM = "COLLAPSIBLE_ITEM",
    COLLAPSIBLE_ITEM_TITLE = "COLLAPSIBLE_ITEM_TITLE",
    COLLAPSIBLE_ITEM_BODY = "COLLAPSIBLE_ITEM_BODY",
    TABLE_CELL = "TABLE_CELL",
    TABLE_ROW = "TABLE_ROW",
    EXTERNAL = "EXTERNAL",
    AUDIO = "AUDIO",
    CAPTION = "CAPTION",
    LAYOUT = "LAYOUT",
    LAYOUT_CELL = "LAYOUT_CELL"
}
/** @enumType */
type NodeTypeWithLiterals = NodeType | 'PARAGRAPH' | 'TEXT' | 'HEADING' | 'BULLETED_LIST' | 'ORDERED_LIST' | 'LIST_ITEM' | 'BLOCKQUOTE' | 'CODE_BLOCK' | 'VIDEO' | 'DIVIDER' | 'FILE' | 'GALLERY' | 'GIF' | 'HTML' | 'IMAGE' | 'LINK_PREVIEW' | 'MAP' | 'POLL' | 'APP_EMBED' | 'BUTTON' | 'COLLAPSIBLE_LIST' | 'TABLE' | 'EMBED' | 'COLLAPSIBLE_ITEM' | 'COLLAPSIBLE_ITEM_TITLE' | 'COLLAPSIBLE_ITEM_BODY' | 'TABLE_CELL' | 'TABLE_ROW' | 'EXTERNAL' | 'AUDIO' | 'CAPTION' | 'LAYOUT' | 'LAYOUT_CELL';
interface NodeStyle {
    /** The top padding value in pixels. */
    paddingTop?: string | null;
    /** The bottom padding value in pixels. */
    paddingBottom?: string | null;
    /** The background color as a hexadecimal value. */
    backgroundColor?: string | null;
}
interface ButtonData {
    /** Styling for the button's container. */
    containerData?: PluginContainerData;
    /** The button type. */
    type?: TypeWithLiterals;
    /** Styling for the button. */
    styles?: Styles;
    /** The text to display on the button. */
    text?: string | null;
    /** Button link details. */
    link?: Link;
}
interface Border {
    /**
     * Deprecated: Use `borderWidth` in `styles` instead.
     * @deprecated
     */
    width?: number | null;
    /**
     * Deprecated: Use `borderRadius` in `styles` instead.
     * @deprecated
     */
    radius?: number | null;
}
interface Colors {
    /**
     * Deprecated: Use `textColor` in `styles` instead.
     * @deprecated
     */
    text?: string | null;
    /**
     * Deprecated: Use `borderColor` in `styles` instead.
     * @deprecated
     */
    border?: string | null;
    /**
     * Deprecated: Use `backgroundColor` in `styles` instead.
     * @deprecated
     */
    background?: string | null;
}
interface PluginContainerData {
    /** The width of the node when it's displayed. */
    width?: PluginContainerDataWidth;
    /** The node's alignment within its container. */
    alignment?: PluginContainerDataAlignmentWithLiterals;
    /** Spoiler cover settings for the node. */
    spoiler?: Spoiler;
    /** The height of the node when it's displayed. */
    height?: Height;
    /** Sets whether text should wrap around this node when it's displayed. If `textWrap` is `false`, the node takes up the width of its container. Defaults to `true` for all node types except 'DIVIVDER' where it defaults to `false`. */
    textWrap?: boolean | null;
}
declare enum WidthType {
    /** Width matches the content width */
    CONTENT = "CONTENT",
    /** Small Width */
    SMALL = "SMALL",
    /** Width will match the original asset width */
    ORIGINAL = "ORIGINAL",
    /** coast-to-coast display */
    FULL_WIDTH = "FULL_WIDTH"
}
/** @enumType */
type WidthTypeWithLiterals = WidthType | 'CONTENT' | 'SMALL' | 'ORIGINAL' | 'FULL_WIDTH';
interface PluginContainerDataWidth extends PluginContainerDataWidthDataOneOf {
    /**
     * One of the following predefined width options:
     * `CONTENT`: The width of the container matches the content width.
     * `SMALL`: A small width.
     * `ORIGINAL`: For `imageData` containers only. The width of the container matches the original image width.
     * `FULL_WIDTH`: For `imageData` containers only. The image container takes up the full width of the screen.
     */
    size?: WidthTypeWithLiterals;
    /** A custom width value in pixels. */
    custom?: string | null;
}
/** @oneof */
interface PluginContainerDataWidthDataOneOf {
    /**
     * One of the following predefined width options:
     * `CONTENT`: The width of the container matches the content width.
     * `SMALL`: A small width.
     * `ORIGINAL`: For `imageData` containers only. The width of the container matches the original image width.
     * `FULL_WIDTH`: For `imageData` containers only. The image container takes up the full width of the screen.
     */
    size?: WidthTypeWithLiterals;
    /** A custom width value in pixels. */
    custom?: string | null;
}
declare enum PluginContainerDataAlignment {
    /** Center Alignment */
    CENTER = "CENTER",
    /** Left Alignment */
    LEFT = "LEFT",
    /** Right Alignment */
    RIGHT = "RIGHT"
}
/** @enumType */
type PluginContainerDataAlignmentWithLiterals = PluginContainerDataAlignment | 'CENTER' | 'LEFT' | 'RIGHT';
interface Spoiler {
    /** Sets whether the spoiler cover is enabled for this node. Defaults to `false`. */
    enabled?: boolean | null;
    /** The description displayed on top of the spoiler cover. */
    description?: string | null;
    /** The text for the button used to remove the spoiler cover. */
    buttonText?: string | null;
}
interface Height {
    /** A custom height value in pixels. */
    custom?: string | null;
}
declare enum Type {
    /** Regular link button */
    LINK = "LINK",
    /** Triggers custom action that is defined in plugin configuration by the consumer */
    ACTION = "ACTION"
}
/** @enumType */
type TypeWithLiterals = Type | 'LINK' | 'ACTION';
interface Styles {
    /**
     * Deprecated: Use `borderWidth` and `borderRadius` instead.
     * @deprecated
     */
    border?: Border;
    /**
     * Deprecated: Use `textColor`, `borderColor` and `backgroundColor` instead.
     * @deprecated
     */
    colors?: Colors;
    /** Border width in pixels. */
    borderWidth?: number | null;
    /**
     * Deprecated: Use `borderWidth` for normal/hover states instead.
     * @deprecated
     */
    borderWidthHover?: number | null;
    /** Border radius in pixels. */
    borderRadius?: number | null;
    /**
     * Border color as a hexadecimal value.
     * @format COLOR_HEX
     */
    borderColor?: string | null;
    /**
     * Border color as a hexadecimal value (hover state).
     * @format COLOR_HEX
     */
    borderColorHover?: string | null;
    /**
     * Text color as a hexadecimal value.
     * @format COLOR_HEX
     */
    textColor?: string | null;
    /**
     * Text color as a hexadecimal value (hover state).
     * @format COLOR_HEX
     */
    textColorHover?: string | null;
    /**
     * Background color as a hexadecimal value.
     * @format COLOR_HEX
     */
    backgroundColor?: string | null;
    /**
     * Background color as a hexadecimal value (hover state).
     * @format COLOR_HEX
     */
    backgroundColorHover?: string | null;
    /** Button size option, one of `SMALL`, `MEDIUM` or `LARGE`. Defaults to `MEDIUM`. */
    buttonSize?: string | null;
}
interface Link extends LinkDataOneOf {
    /** The absolute URL for the linked document. */
    url?: string;
    /** The target node's ID. Used for linking to another node in this object. */
    anchor?: string;
    /**
     * he HTML `target` attribute value for the link. This property defines where the linked document opens as follows:
     * `SELF` - Default. Opens the linked document in the same frame as the link.
     * `BLANK` - Opens the linked document in a new browser tab or window.
     * `PARENT` - Opens the linked document in the link's parent frame.
     * `TOP` - Opens the linked document in the full body of the link's browser tab or window.
     */
    target?: TargetWithLiterals;
    /** The HTML `rel` attribute value for the link. This object specifies the relationship between the current document and the linked document. */
    rel?: Rel;
    /** A serialized object used for a custom or external link panel. */
    customData?: string | null;
}
/** @oneof */
interface LinkDataOneOf {
    /** The absolute URL for the linked document. */
    url?: string;
    /** The target node's ID. Used for linking to another node in this object. */
    anchor?: string;
}
declare enum Target {
    /** Opens the linked document in the same frame as it was clicked (this is default) */
    SELF = "SELF",
    /** Opens the linked document in a new window or tab */
    BLANK = "BLANK",
    /** Opens the linked document in the parent frame */
    PARENT = "PARENT",
    /** Opens the linked document in the full body of the window */
    TOP = "TOP"
}
/** @enumType */
type TargetWithLiterals = Target | 'SELF' | 'BLANK' | 'PARENT' | 'TOP';
interface Rel {
    /** Indicates to search engine crawlers not to follow the link. Defaults to `false`. */
    nofollow?: boolean | null;
    /** Indicates to search engine crawlers that the link is a paid placement such as sponsored content or an advertisement. Defaults to `false`. */
    sponsored?: boolean | null;
    /** Indicates that this link is user-generated content and isn't necessarily trusted or endorsed by the page’s author. For example, a link in a fourm post. Defaults to `false`. */
    ugc?: boolean | null;
    /** Indicates that this link protect referral information from being passed to the target website. */
    noreferrer?: boolean | null;
}
interface CodeBlockData {
    /** Styling for the code block's text. */
    textStyle?: TextStyle;
}
interface TextStyle {
    /** Text alignment. Defaults to `AUTO`. */
    textAlignment?: TextAlignmentWithLiterals;
    /** A CSS `line-height` value for the text expressed as a ratio relative to the font size. For example, if the font size is 20px, a `lineHeight` value of `'1.5'`` results in a line height of 30px. */
    lineHeight?: string | null;
}
declare enum TextAlignment {
    /** browser default, eqivalent to `initial` */
    AUTO = "AUTO",
    /** Left align */
    LEFT = "LEFT",
    /** Right align */
    RIGHT = "RIGHT",
    /** Center align */
    CENTER = "CENTER",
    /** Text is spaced to line up its left and right edges to the left and right edges of the line box, except for the last line */
    JUSTIFY = "JUSTIFY"
}
/** @enumType */
type TextAlignmentWithLiterals = TextAlignment | 'AUTO' | 'LEFT' | 'RIGHT' | 'CENTER' | 'JUSTIFY';
interface DividerData {
    /** Styling for the divider's container. */
    containerData?: PluginContainerData;
    /** Divider line style. */
    lineStyle?: LineStyleWithLiterals;
    /** Divider width. */
    width?: WidthWithLiterals;
    /** Divider alignment. */
    alignment?: AlignmentWithLiterals;
}
declare enum LineStyle {
    /** Single Line */
    SINGLE = "SINGLE",
    /** Double Line */
    DOUBLE = "DOUBLE",
    /** Dashed Line */
    DASHED = "DASHED",
    /** Dotted Line */
    DOTTED = "DOTTED"
}
/** @enumType */
type LineStyleWithLiterals = LineStyle | 'SINGLE' | 'DOUBLE' | 'DASHED' | 'DOTTED';
declare enum Width {
    /** Large line */
    LARGE = "LARGE",
    /** Medium line */
    MEDIUM = "MEDIUM",
    /** Small line */
    SMALL = "SMALL"
}
/** @enumType */
type WidthWithLiterals = Width | 'LARGE' | 'MEDIUM' | 'SMALL';
declare enum Alignment {
    /** Center alignment */
    CENTER = "CENTER",
    /** Left alignment */
    LEFT = "LEFT",
    /** Right alignment */
    RIGHT = "RIGHT"
}
/** @enumType */
type AlignmentWithLiterals = Alignment | 'CENTER' | 'LEFT' | 'RIGHT';
interface FileData {
    /** Styling for the file's container. */
    containerData?: PluginContainerData;
    /** The source for the file's data. */
    src?: FileSource;
    /** File name. */
    name?: string | null;
    /** File type. */
    type?: string | null;
    /**
     * Use `sizeInKb` instead.
     * @deprecated
     */
    size?: number | null;
    /** Settings for PDF files. */
    pdfSettings?: PDFSettings;
    /** File MIME type. */
    mimeType?: string | null;
    /** File path. */
    path?: string | null;
    /** File size in KB. */
    sizeInKb?: string | null;
}
declare enum ViewMode {
    /** No PDF view */
    NONE = "NONE",
    /** Full PDF view */
    FULL = "FULL",
    /** Mini PDF view */
    MINI = "MINI"
}
/** @enumType */
type ViewModeWithLiterals = ViewMode | 'NONE' | 'FULL' | 'MINI';
interface FileSource extends FileSourceDataOneOf {
    /** The absolute URL for the file's source. */
    url?: string | null;
    /**
     * Custom ID. Use `id` instead.
     * @deprecated
     */
    custom?: string | null;
    /** An ID that's resolved to a URL by a resolver function. */
    id?: string | null;
    /** Indicates whether the file's source is private. Defaults to `false`. */
    private?: boolean | null;
}
/** @oneof */
interface FileSourceDataOneOf {
    /** The absolute URL for the file's source. */
    url?: string | null;
    /**
     * Custom ID. Use `id` instead.
     * @deprecated
     */
    custom?: string | null;
    /** An ID that's resolved to a URL by a resolver function. */
    id?: string | null;
}
interface PDFSettings {
    /**
     * PDF view mode. One of the following:
     * `NONE` : The PDF isn't displayed.
     * `FULL` : A full page view of the PDF is displayed.
     * `MINI` : A mini view of the PDF is displayed.
     */
    viewMode?: ViewModeWithLiterals;
    /** Sets whether the PDF download button is disabled. Defaults to `false`. */
    disableDownload?: boolean | null;
    /** Sets whether the PDF print button is disabled. Defaults to `false`. */
    disablePrint?: boolean | null;
}
interface GalleryData {
    /** Styling for the gallery's container. */
    containerData?: PluginContainerData;
    /** The items in the gallery. */
    items?: Item[];
    /** Options for defining the gallery's appearance. */
    options?: GalleryOptions;
    /** Sets whether the gallery's expand button is disabled. Defaults to `false`. */
    disableExpand?: boolean | null;
    /** Sets whether the gallery's download button is disabled. Defaults to `false`. */
    disableDownload?: boolean | null;
}
interface Media {
    /** The source for the media's data. */
    src?: FileSource;
    /** Media width in pixels. */
    width?: number | null;
    /** Media height in pixels. */
    height?: number | null;
    /** Media duration in seconds. Only relevant for audio and video files. */
    duration?: number | null;
}
interface Image {
    /** Image file details. */
    media?: Media;
    /** Link details for images that are links. */
    link?: Link;
}
interface Video {
    /** Video file details. */
    media?: Media;
    /** Video thumbnail file details. */
    thumbnail?: Media;
}
interface Item extends ItemDataOneOf {
    /** An image item. */
    image?: Image;
    /** A video item. */
    video?: Video;
    /** Item title. */
    title?: string | null;
    /** Item's alternative text. */
    altText?: string | null;
}
/** @oneof */
interface ItemDataOneOf {
    /** An image item. */
    image?: Image;
    /** A video item. */
    video?: Video;
}
interface GalleryOptions {
    /** Gallery layout. */
    layout?: Layout;
    /** Styling for gallery items. */
    item?: ItemStyle;
    /** Styling for gallery thumbnail images. */
    thumbnails?: Thumbnails;
}
declare enum LayoutType {
    /** Collage type */
    COLLAGE = "COLLAGE",
    /** Masonry type */
    MASONRY = "MASONRY",
    /** Grid type */
    GRID = "GRID",
    /** Thumbnail type */
    THUMBNAIL = "THUMBNAIL",
    /** Slider type */
    SLIDER = "SLIDER",
    /** Slideshow type */
    SLIDESHOW = "SLIDESHOW",
    /** Panorama type */
    PANORAMA = "PANORAMA",
    /** Column type */
    COLUMN = "COLUMN",
    /** Magic type */
    MAGIC = "MAGIC",
    /** Fullsize images type */
    FULLSIZE = "FULLSIZE"
}
/** @enumType */
type LayoutTypeWithLiterals = LayoutType | 'COLLAGE' | 'MASONRY' | 'GRID' | 'THUMBNAIL' | 'SLIDER' | 'SLIDESHOW' | 'PANORAMA' | 'COLUMN' | 'MAGIC' | 'FULLSIZE';
declare enum Orientation {
    /** Rows Orientation */
    ROWS = "ROWS",
    /** Columns Orientation */
    COLUMNS = "COLUMNS"
}
/** @enumType */
type OrientationWithLiterals = Orientation | 'ROWS' | 'COLUMNS';
declare enum Crop {
    /** Crop to fill */
    FILL = "FILL",
    /** Crop to fit */
    FIT = "FIT"
}
/** @enumType */
type CropWithLiterals = Crop | 'FILL' | 'FIT';
declare enum ThumbnailsAlignment {
    /** Top alignment */
    TOP = "TOP",
    /** Right alignment */
    RIGHT = "RIGHT",
    /** Bottom alignment */
    BOTTOM = "BOTTOM",
    /** Left alignment */
    LEFT = "LEFT",
    /** No thumbnail */
    NONE = "NONE"
}
/** @enumType */
type ThumbnailsAlignmentWithLiterals = ThumbnailsAlignment | 'TOP' | 'RIGHT' | 'BOTTOM' | 'LEFT' | 'NONE';
interface Layout {
    /** Gallery layout type. */
    type?: LayoutTypeWithLiterals;
    /** Sets whether horizontal scroll is enabled. Defaults to `true` unless the layout `type` is set to `GRID` or `COLLAGE`. */
    horizontalScroll?: boolean | null;
    /** Gallery orientation. */
    orientation?: OrientationWithLiterals;
    /** The number of columns to display on full size screens. */
    numberOfColumns?: number | null;
    /** The number of columns to display on mobile screens. */
    mobileNumberOfColumns?: number | null;
}
interface ItemStyle {
    /** Desirable dimension for each item in pixels (behvaior changes according to gallery type) */
    targetSize?: number | null;
    /** Item ratio */
    ratio?: number | null;
    /** Sets how item images are cropped. */
    crop?: CropWithLiterals;
    /** The spacing between items in pixels. */
    spacing?: number | null;
}
interface Thumbnails {
    /** Thumbnail alignment. */
    placement?: ThumbnailsAlignmentWithLiterals;
    /** Spacing between thumbnails in pixels. */
    spacing?: number | null;
}
interface GIFData {
    /** Styling for the GIF's container. */
    containerData?: PluginContainerData;
    /** The source of the full size GIF. */
    original?: GIF;
    /** The source of the downsized GIF. */
    downsized?: GIF;
    /** Height in pixels. */
    height?: number;
    /** Width in pixels. */
    width?: number;
    /** Type of GIF (Sticker or NORMAL). Defaults to `NORMAL`. */
    gifType?: GIFTypeWithLiterals;
}
interface GIF {
    /**
     * GIF format URL.
     * @format WEB_URL
     */
    gif?: string | null;
    /**
     * MP4 format URL.
     * @format WEB_URL
     */
    mp4?: string | null;
    /**
     * Thumbnail URL.
     * @format WEB_URL
     */
    still?: string | null;
}
declare enum GIFType {
    NORMAL = "NORMAL",
    STICKER = "STICKER"
}
/** @enumType */
type GIFTypeWithLiterals = GIFType | 'NORMAL' | 'STICKER';
interface HeadingData {
    /** Heading level from 1-6. */
    level?: number;
    /** Styling for the heading text. */
    textStyle?: TextStyle;
    /** Indentation level from 1-4. */
    indentation?: number | null;
}
interface HTMLData extends HTMLDataDataOneOf {
    /** The URL for the HTML code for the node. */
    url?: string;
    /** The HTML code for the node. */
    html?: string;
    /**
     * Whether this is an AdSense element. Use `source` instead.
     * @deprecated
     */
    isAdsense?: boolean | null;
    /** Styling for the HTML node's container. Height property is irrelevant for HTML embeds when autoHeight is set to `true`. */
    containerData?: PluginContainerData;
    /** The type of HTML code. */
    source?: SourceWithLiterals;
    /** If container height is aligned with its content height. Defaults to `true`. */
    autoHeight?: boolean | null;
}
/** @oneof */
interface HTMLDataDataOneOf {
    /** The URL for the HTML code for the node. */
    url?: string;
    /** The HTML code for the node. */
    html?: string;
    /**
     * Whether this is an AdSense element. Use `source` instead.
     * @deprecated
     */
    isAdsense?: boolean | null;
}
declare enum Source {
    HTML = "HTML",
    ADSENSE = "ADSENSE"
}
/** @enumType */
type SourceWithLiterals = Source | 'HTML' | 'ADSENSE';
interface ImageData {
    /** Styling for the image's container. */
    containerData?: PluginContainerData;
    /** Image file details. */
    image?: Media;
    /** Link details for images that are links. */
    link?: Link;
    /** Sets whether the image expands to full screen when clicked. Defaults to `false`. */
    disableExpand?: boolean | null;
    /** Image's alternative text. */
    altText?: string | null;
    /**
     * Deprecated: use Caption node instead.
     * @deprecated
     */
    caption?: string | null;
    /** Sets whether the image's download button is disabled. Defaults to `false`. */
    disableDownload?: boolean | null;
    /** Sets whether the image is decorative and does not need an explanation. Defaults to `false`. */
    decorative?: boolean | null;
    /** Styling for the image. */
    styles?: ImageDataStyles;
}
interface StylesBorder {
    /** Border width in pixels. */
    width?: number | null;
    /**
     * Border color as a hexadecimal value.
     * @format COLOR_HEX
     */
    color?: string | null;
    /** Border radius in pixels. */
    radius?: number | null;
}
interface ImageDataStyles {
    /** Border attributes. */
    border?: StylesBorder;
}
interface LinkPreviewData {
    /** Styling for the link preview's container. */
    containerData?: PluginContainerData;
    /** Link details. */
    link?: Link;
    /** Preview title. */
    title?: string | null;
    /** Preview thumbnail URL. */
    thumbnailUrl?: string | null;
    /** Preview description. */
    description?: string | null;
    /** The preview content as HTML. */
    html?: string | null;
    /** Styling for the link preview. */
    styles?: LinkPreviewDataStyles;
}
declare enum Position {
    /** Thumbnail positioned at the start (left in LTR layouts, right in RTL layouts) */
    START = "START",
    /** Thumbnail positioned at the end (right in LTR layouts, left in RTL layouts) */
    END = "END",
    /** Thumbnail positioned at the top */
    TOP = "TOP",
    /** Thumbnail hidden and not displayed */
    HIDDEN = "HIDDEN"
}
/** @enumType */
type PositionWithLiterals = Position | 'START' | 'END' | 'TOP' | 'HIDDEN';
interface LinkPreviewDataStyles {
    /**
     * Background color as a hexadecimal value.
     * @format COLOR_HEX
     */
    backgroundColor?: string | null;
    /**
     * Title color as a hexadecimal value.
     * @format COLOR_HEX
     */
    titleColor?: string | null;
    /**
     * Subtitle color as a hexadecimal value.
     * @format COLOR_HEX
     */
    subtitleColor?: string | null;
    /**
     * Link color as a hexadecimal value.
     * @format COLOR_HEX
     */
    linkColor?: string | null;
    /** Border width in pixels. */
    borderWidth?: number | null;
    /** Border radius in pixels. */
    borderRadius?: number | null;
    /**
     * Border color as a hexadecimal value.
     * @format COLOR_HEX
     */
    borderColor?: string | null;
    /** Position of thumbnail. Defaults to `START`. */
    thumbnailPosition?: PositionWithLiterals;
}
interface MapData {
    /** Styling for the map's container. */
    containerData?: PluginContainerData;
    /** Map settings. */
    mapSettings?: MapSettings;
}
interface MapSettings {
    /** The address to display on the map. */
    address?: string | null;
    /** Sets whether the map is draggable. */
    draggable?: boolean | null;
    /** Sets whether the location marker is visible. */
    marker?: boolean | null;
    /** Sets whether street view control is enabled. */
    streetViewControl?: boolean | null;
    /** Sets whether zoom control is enabled. */
    zoomControl?: boolean | null;
    /** Location latitude. */
    lat?: number | null;
    /** Location longitude. */
    lng?: number | null;
    /** Location name. */
    locationName?: string | null;
    /** Sets whether view mode control is enabled. */
    viewModeControl?: boolean | null;
    /** Initial zoom value. */
    initialZoom?: number | null;
    /** Map type. `HYBRID` is a combination of the `ROADMAP` and `SATELLITE` map types. */
    mapType?: MapTypeWithLiterals;
}
declare enum MapType {
    /** Roadmap map type */
    ROADMAP = "ROADMAP",
    /** Satellite map type */
    SATELITE = "SATELITE",
    /** Hybrid map type */
    HYBRID = "HYBRID",
    /** Terrain map type */
    TERRAIN = "TERRAIN"
}
/** @enumType */
type MapTypeWithLiterals = MapType | 'ROADMAP' | 'SATELITE' | 'HYBRID' | 'TERRAIN';
interface ParagraphData {
    /** Styling for the paragraph text. */
    textStyle?: TextStyle;
    /** Indentation level from 1-4. */
    indentation?: number | null;
    /** Paragraph level */
    level?: number | null;
}
interface PollData {
    /** Styling for the poll's container. */
    containerData?: PluginContainerData;
    /** Poll data. */
    poll?: Poll;
    /** Layout settings for the poll and voting options. */
    layout?: PollDataLayout;
    /** Styling for the poll and voting options. */
    design?: Design;
}
declare enum ViewRole {
    /** Only Poll creator can view the results */
    CREATOR = "CREATOR",
    /** Anyone who voted can see the results */
    VOTERS = "VOTERS",
    /** Anyone can see the results, even if one didn't vote */
    EVERYONE = "EVERYONE"
}
/** @enumType */
type ViewRoleWithLiterals = ViewRole | 'CREATOR' | 'VOTERS' | 'EVERYONE';
declare enum VoteRole {
    /** Logged in member */
    SITE_MEMBERS = "SITE_MEMBERS",
    /** Anyone */
    ALL = "ALL"
}
/** @enumType */
type VoteRoleWithLiterals = VoteRole | 'SITE_MEMBERS' | 'ALL';
interface Permissions {
    /** Sets who can view the poll results. */
    view?: ViewRoleWithLiterals;
    /** Sets who can vote. */
    vote?: VoteRoleWithLiterals;
    /** Sets whether one voter can vote multiple times. Defaults to `false`. */
    allowMultipleVotes?: boolean | null;
}
interface Option {
    /** Option ID. */
    id?: string | null;
    /** Option title. */
    title?: string | null;
    /** The image displayed with the option. */
    image?: Media;
}
interface Settings {
    /** Permissions settings for voting. */
    permissions?: Permissions;
    /** Sets whether voters are displayed in the vote results. Defaults to `true`. */
    showVoters?: boolean | null;
    /** Sets whether the vote count is displayed. Defaults to `true`. */
    showVotesCount?: boolean | null;
}
declare enum PollLayoutType {
    /** List */
    LIST = "LIST",
    /** Grid */
    GRID = "GRID"
}
/** @enumType */
type PollLayoutTypeWithLiterals = PollLayoutType | 'LIST' | 'GRID';
declare enum PollLayoutDirection {
    /** Left-to-right */
    LTR = "LTR",
    /** Right-to-left */
    RTL = "RTL"
}
/** @enumType */
type PollLayoutDirectionWithLiterals = PollLayoutDirection | 'LTR' | 'RTL';
interface PollLayout {
    /** The layout for displaying the voting options. */
    type?: PollLayoutTypeWithLiterals;
    /** The direction of the text displayed in the voting options. Text can be displayed either right-to-left or left-to-right. */
    direction?: PollLayoutDirectionWithLiterals;
    /** Sets whether to display the main poll image. Defaults to `false`. */
    enableImage?: boolean | null;
}
interface OptionLayout {
    /** Sets whether to display option images. Defaults to `false`. */
    enableImage?: boolean | null;
}
declare enum BackgroundType {
    /** Color background type */
    COLOR = "COLOR",
    /** Image background type */
    IMAGE = "IMAGE",
    /** Gradiant background type */
    GRADIENT = "GRADIENT"
}
/** @enumType */
type BackgroundTypeWithLiterals = BackgroundType | 'COLOR' | 'IMAGE' | 'GRADIENT';
interface Gradient {
    /** The gradient angle in degrees. */
    angle?: number | null;
    /**
     * The start color as a hexademical value.
     * @format COLOR_HEX
     */
    startColor?: string | null;
    /**
     * The end color as a hexademical value.
     * @format COLOR_HEX
     */
    lastColor?: string | null;
}
interface Background extends BackgroundBackgroundOneOf {
    /**
     * The background color as a hexademical value.
     * @format COLOR_HEX
     */
    color?: string | null;
    /** An image to use for the background. */
    image?: Media;
    /** Details for a gradient background. */
    gradient?: Gradient;
    /** Background type. For each option, include the relevant details. */
    type?: BackgroundTypeWithLiterals;
}
/** @oneof */
interface BackgroundBackgroundOneOf {
    /**
     * The background color as a hexademical value.
     * @format COLOR_HEX
     */
    color?: string | null;
    /** An image to use for the background. */
    image?: Media;
    /** Details for a gradient background. */
    gradient?: Gradient;
}
interface PollDesign {
    /** Background styling. */
    background?: Background;
    /** Border radius in pixels. */
    borderRadius?: number | null;
}
interface OptionDesign {
    /** Border radius in pixels. */
    borderRadius?: number | null;
}
interface Poll {
    /** Poll ID. */
    id?: string | null;
    /** Poll title. */
    title?: string | null;
    /** Poll creator ID. */
    creatorId?: string | null;
    /** Main poll image. */
    image?: Media;
    /** Voting options. */
    options?: Option[];
    /** The poll's permissions and display settings. */
    settings?: Settings;
}
interface PollDataLayout {
    /** Poll layout settings. */
    poll?: PollLayout;
    /** Voting otpions layout settings. */
    options?: OptionLayout;
}
interface Design {
    /** Styling for the poll. */
    poll?: PollDesign;
    /** Styling for voting options. */
    options?: OptionDesign;
}
interface TextData {
    /** The text to apply decorations to. */
    text?: string;
    /** The decorations to apply. */
    decorations?: Decoration[];
}
/** Adds appearence changes to text */
interface Decoration extends DecorationDataOneOf {
    /** Data for an anchor link decoration. */
    anchorData?: AnchorData;
    /** Data for a color decoration. */
    colorData?: ColorData;
    /** Data for an external link decoration. */
    linkData?: LinkData;
    /** Data for a mention decoration. */
    mentionData?: MentionData;
    /** Data for a font size decoration. */
    fontSizeData?: FontSizeData;
    /** Font weight for a bold decoration. */
    fontWeightValue?: number | null;
    /** Data for an italic decoration. Defaults to `true`. */
    italicData?: boolean | null;
    /** Data for an underline decoration. Defaults to `true`. */
    underlineData?: boolean | null;
    /** Data for a spoiler decoration. */
    spoilerData?: SpoilerData;
    /** Data for a strikethrough decoration. Defaults to `true`. */
    strikethroughData?: boolean | null;
    /** Data for a superscript decoration. Defaults to `true`. */
    superscriptData?: boolean | null;
    /** Data for a subscript decoration. Defaults to `true`. */
    subscriptData?: boolean | null;
    /** The type of decoration to apply. */
    type?: DecorationTypeWithLiterals;
}
/** @oneof */
interface DecorationDataOneOf {
    /** Data for an anchor link decoration. */
    anchorData?: AnchorData;
    /** Data for a color decoration. */
    colorData?: ColorData;
    /** Data for an external link decoration. */
    linkData?: LinkData;
    /** Data for a mention decoration. */
    mentionData?: MentionData;
    /** Data for a font size decoration. */
    fontSizeData?: FontSizeData;
    /** Font weight for a bold decoration. */
    fontWeightValue?: number | null;
    /** Data for an italic decoration. Defaults to `true`. */
    italicData?: boolean | null;
    /** Data for an underline decoration. Defaults to `true`. */
    underlineData?: boolean | null;
    /** Data for a spoiler decoration. */
    spoilerData?: SpoilerData;
    /** Data for a strikethrough decoration. Defaults to `true`. */
    strikethroughData?: boolean | null;
    /** Data for a superscript decoration. Defaults to `true`. */
    superscriptData?: boolean | null;
    /** Data for a subscript decoration. Defaults to `true`. */
    subscriptData?: boolean | null;
}
declare enum DecorationType {
    BOLD = "BOLD",
    ITALIC = "ITALIC",
    UNDERLINE = "UNDERLINE",
    SPOILER = "SPOILER",
    ANCHOR = "ANCHOR",
    MENTION = "MENTION",
    LINK = "LINK",
    COLOR = "COLOR",
    FONT_SIZE = "FONT_SIZE",
    EXTERNAL = "EXTERNAL",
    STRIKETHROUGH = "STRIKETHROUGH",
    SUPERSCRIPT = "SUPERSCRIPT",
    SUBSCRIPT = "SUBSCRIPT"
}
/** @enumType */
type DecorationTypeWithLiterals = DecorationType | 'BOLD' | 'ITALIC' | 'UNDERLINE' | 'SPOILER' | 'ANCHOR' | 'MENTION' | 'LINK' | 'COLOR' | 'FONT_SIZE' | 'EXTERNAL' | 'STRIKETHROUGH' | 'SUPERSCRIPT' | 'SUBSCRIPT';
interface AnchorData {
    /** The target node's ID. */
    anchor?: string;
}
interface ColorData {
    /** The text's background color as a hexadecimal value. */
    background?: string | null;
    /** The text's foreground color as a hexadecimal value. */
    foreground?: string | null;
}
interface LinkData {
    /** Link details. */
    link?: Link;
}
interface MentionData {
    /** The mentioned user's name. */
    name?: string;
    /** The version of the user's name that appears after the `@` character in the mention. */
    slug?: string;
    /** Mentioned user's ID. */
    id?: string | null;
}
interface FontSizeData {
    /** The units used for the font size. */
    unit?: FontTypeWithLiterals;
    /** Font size value. */
    value?: number | null;
}
declare enum FontType {
    PX = "PX",
    EM = "EM"
}
/** @enumType */
type FontTypeWithLiterals = FontType | 'PX' | 'EM';
interface SpoilerData {
    /** Spoiler ID. */
    id?: string | null;
}
interface AppEmbedData extends AppEmbedDataAppDataOneOf {
    /** Data for embedded Wix Bookings content. */
    bookingData?: BookingData;
    /** Data for embedded Wix Events content. */
    eventData?: EventData;
    /** The type of Wix App content being embedded. */
    type?: AppTypeWithLiterals;
    /** The ID of the embedded content. */
    itemId?: string | null;
    /** The name of the embedded content. */
    name?: string | null;
    /**
     * Deprecated: Use `image` instead.
     * @deprecated
     */
    imageSrc?: string | null;
    /** The URL for the embedded content. */
    url?: string | null;
    /** An image for the embedded content. */
    image?: Media;
}
/** @oneof */
interface AppEmbedDataAppDataOneOf {
    /** Data for embedded Wix Bookings content. */
    bookingData?: BookingData;
    /** Data for embedded Wix Events content. */
    eventData?: EventData;
}
declare enum AppType {
    PRODUCT = "PRODUCT",
    EVENT = "EVENT",
    BOOKING = "BOOKING"
}
/** @enumType */
type AppTypeWithLiterals = AppType | 'PRODUCT' | 'EVENT' | 'BOOKING';
interface BookingData {
    /** Booking duration in minutes. */
    durations?: string | null;
}
interface EventData {
    /** Event schedule. */
    scheduling?: string | null;
    /** Event location. */
    location?: string | null;
}
interface VideoData {
    /** Styling for the video's container. */
    containerData?: PluginContainerData;
    /** Video details. */
    video?: Media;
    /** Video thumbnail details. */
    thumbnail?: Media;
    /** Sets whether the video's download button is disabled. Defaults to `false`. */
    disableDownload?: boolean | null;
    /** Video title. */
    title?: string | null;
    /** Video options. */
    options?: PlaybackOptions;
}
interface PlaybackOptions {
    /** Sets whether the media will automatically start playing. */
    autoPlay?: boolean | null;
    /** Sets whether media's will be looped. */
    playInLoop?: boolean | null;
    /** Sets whether media's controls will be shown. */
    showControls?: boolean | null;
}
interface EmbedData {
    /** Styling for the oEmbed node's container. */
    containerData?: PluginContainerData;
    /** An [oEmbed](https://www.oembed.com) object. */
    oembed?: Oembed;
    /** Origin asset source. */
    src?: string | null;
}
interface Oembed {
    /** The resource type. */
    type?: string | null;
    /** The width of the resource specified in the `url` property in pixels. */
    width?: number | null;
    /** The height of the resource specified in the `url` property in pixels. */
    height?: number | null;
    /** Resource title. */
    title?: string | null;
    /** The source URL for the resource. */
    url?: string | null;
    /** HTML for embedding a video player. The HTML should have no padding or margins. */
    html?: string | null;
    /** The name of the author or owner of the resource. */
    authorName?: string | null;
    /** The URL for the author or owner of the resource. */
    authorUrl?: string | null;
    /** The name of the resource provider. */
    providerName?: string | null;
    /** The URL for the resource provider. */
    providerUrl?: string | null;
    /** The URL for a thumbnail image for the resource. If this property is defined, `thumbnailWidth` and `thumbnailHeight` must also be defined. */
    thumbnailUrl?: string | null;
    /** The width of the resource's thumbnail image. If this property is defined, `thumbnailUrl` and `thumbnailHeight` must also be defined. */
    thumbnailWidth?: string | null;
    /** The height of the resource's thumbnail image. If this property is defined, `thumbnailUrl` and `thumbnailWidth`must also be defined. */
    thumbnailHeight?: string | null;
    /** The URL for an embedded viedo. */
    videoUrl?: string | null;
    /** The oEmbed version number.  This value must be `1.0`. */
    version?: string | null;
}
interface CollapsibleListData {
    /** Styling for the collapsible list's container. */
    containerData?: PluginContainerData;
    /** If `true`, only one item can be expanded at a time. Defaults to `false`. */
    expandOnlyOne?: boolean | null;
    /** Sets which items are expanded when the page loads. */
    initialExpandedItems?: InitialExpandedItemsWithLiterals;
    /** The direction of the text in the list. Either left-to-right or right-to-left. */
    direction?: DirectionWithLiterals;
    /** If `true`, The collapsible item will appear in search results as an FAQ. */
    isQapageData?: boolean | null;
}
declare enum InitialExpandedItems {
    /** First item will be expended initally */
    FIRST = "FIRST",
    /** All items will expended initally */
    ALL = "ALL",
    /** All items collapsed initally */
    NONE = "NONE"
}
/** @enumType */
type InitialExpandedItemsWithLiterals = InitialExpandedItems | 'FIRST' | 'ALL' | 'NONE';
declare enum Direction {
    /** Left-to-right */
    LTR = "LTR",
    /** Right-to-left */
    RTL = "RTL"
}
/** @enumType */
type DirectionWithLiterals = Direction | 'LTR' | 'RTL';
interface TableData {
    /** Styling for the table's container. */
    containerData?: PluginContainerData;
    /** The table's dimensions. */
    dimensions?: Dimensions;
    /**
     * Deprecated: Use `rowHeader` and `columnHeader` instead.
     * @deprecated
     */
    header?: boolean | null;
    /** Sets whether the table's first row is a header. Defaults to `false`. */
    rowHeader?: boolean | null;
    /** Sets whether the table's first column is a header. Defaults to `false`. */
    columnHeader?: boolean | null;
}
interface Dimensions {
    /** An array representing relative width of each column in relation to the other columns. */
    colsWidthRatio?: number[];
    /** An array representing the height of each row in pixels. */
    rowsHeight?: number[];
    /** An array representing the minimum width of each column in pixels. */
    colsMinWidth?: number[];
}
interface TableCellData {
    /** Styling for the cell's background color and text alignment. */
    cellStyle?: CellStyle;
    /** The cell's border colors. */
    borderColors?: BorderColors;
}
declare enum VerticalAlignment {
    /** Top alignment */
    TOP = "TOP",
    /** Middle alignment */
    MIDDLE = "MIDDLE",
    /** Bottom alignment */
    BOTTOM = "BOTTOM"
}
/** @enumType */
type VerticalAlignmentWithLiterals = VerticalAlignment | 'TOP' | 'MIDDLE' | 'BOTTOM';
interface CellStyle {
    /** Vertical alignment for the cell's text. */
    verticalAlignment?: VerticalAlignmentWithLiterals;
    /**
     * Cell background color as a hexadecimal value.
     * @format COLOR_HEX
     */
    backgroundColor?: string | null;
}
interface BorderColors {
    /**
     * Left border color as a hexadecimal value.
     * @format COLOR_HEX
     */
    left?: string | null;
    /**
     * Right border color as a hexadecimal value.
     * @format COLOR_HEX
     */
    right?: string | null;
    /**
     * Top border color as a hexadecimal value.
     * @format COLOR_HEX
     */
    top?: string | null;
    /**
     * Bottom border color as a hexadecimal value.
     * @format COLOR_HEX
     */
    bottom?: string | null;
}
/**
 * `NullValue` is a singleton enumeration to represent the null value for the
 * `Value` type union.
 *
 * The JSON representation for `NullValue` is JSON `null`.
 */
declare enum NullValue {
    /** Null value. */
    NULL_VALUE = "NULL_VALUE"
}
/**
 * `ListValue` is a wrapper around a repeated field of values.
 *
 * The JSON representation for `ListValue` is JSON array.
 */
interface ListValue {
    /** Repeated field of dynamically typed values. */
    values?: any[];
}
interface AudioData {
    /** Styling for the audio node's container. */
    containerData?: PluginContainerData;
    /** Audio file details. */
    audio?: Media;
    /** Sets whether the audio node's download button is disabled. Defaults to `false`. */
    disableDownload?: boolean | null;
    /** Cover image. */
    coverImage?: Media;
    /** Track name. */
    name?: string | null;
    /** Author name. */
    authorName?: string | null;
    /** An HTML version of the audio node. */
    html?: string | null;
}
interface OrderedListData {
    /** Indentation level from 0-4. */
    indentation?: number;
    /** Offset level from 0-4. */
    offset?: number | null;
    /** List start number. */
    start?: number | null;
}
interface BulletedListData {
    /** Indentation level from 0-4. */
    indentation?: number;
    /** Offset level from 0-4. */
    offset?: number | null;
}
interface BlockquoteData {
    /** Indentation level from 1-4. */
    indentation?: number;
}
interface CaptionData {
    textStyle?: TextStyle;
}
interface LayoutCellData {
    /** Size of the cell in 12 columns grid. */
    colSpan?: number | null;
}
interface Metadata {
    /** Schema version. */
    version?: number;
    /**
     * When the object was created.
     * @readonly
     * @deprecated
     */
    createdTimestamp?: Date | null;
    /**
     * When the object was most recently updated.
     * @deprecated
     */
    updatedTimestamp?: Date | null;
    /** Object ID. */
    _id?: string | null;
}
interface DocumentStyle {
    /** Styling for H1 nodes. */
    headerOne?: TextNodeStyle;
    /** Styling for H2 nodes. */
    headerTwo?: TextNodeStyle;
    /** Styling for H3 nodes. */
    headerThree?: TextNodeStyle;
    /** Styling for H4 nodes. */
    headerFour?: TextNodeStyle;
    /** Styling for H5 nodes. */
    headerFive?: TextNodeStyle;
    /** Styling for H6 nodes. */
    headerSix?: TextNodeStyle;
    /** Styling for paragraph nodes. */
    paragraph?: TextNodeStyle;
    /** Styling for block quote nodes. */
    blockquote?: TextNodeStyle;
    /** Styling for code block nodes. */
    codeBlock?: TextNodeStyle;
}
interface TextNodeStyle {
    /** The decorations to apply to the node. */
    decorations?: Decoration[];
    /** Padding and background color for the node. */
    nodeStyle?: NodeStyle;
    /** Line height for text in the node. */
    lineHeight?: string | null;
}
interface Mention extends MentionIdentityOneOf {
    /**
     * Wix user ID.
     * @format GUID
     */
    userId?: string | null;
    /**
     * Member ID. See the Members API for more details.
     * @format GUID
     */
    memberId?: string | null;
    /**
     * Visitor ID.
     * @format GUID
     */
    visitorId?: string | null;
    /**
     * Group ID. See the Groups API for more details.
     * @format GUID
     */
    groupId?: string | null;
}
/** @oneof */
interface MentionIdentityOneOf {
    /**
     * Wix user ID.
     * @format GUID
     */
    userId?: string | null;
    /**
     * Member ID. See the Members API for more details.
     * @format GUID
     */
    memberId?: string | null;
    /**
     * Visitor ID.
     * @format GUID
     */
    visitorId?: string | null;
    /**
     * Group ID. See the Groups API for more details.
     * @format GUID
     */
    groupId?: string | null;
}
interface Attachment extends AttachmentMediaOneOf {
    /** Information about the image. */
    image?: string;
    /** Information about the video. */
    video?: string;
    /** Information about the audio. */
    audio?: string;
    /** Information about the document. */
    document?: string;
    /**
     * Mime type of attachment.
     * @maxLength 3000
     */
    mimeType?: string | null;
}
/** @oneof */
interface AttachmentMediaOneOf {
    /** Information about the image. */
    image?: string;
    /** Information about the video. */
    video?: string;
    /** Information about the audio. */
    audio?: string;
    /** Information about the document. */
    document?: string;
}
interface VideoResolution {
    /** Video URL. */
    url?: string;
    /** Video height. */
    height?: number;
    /** Video width. */
    width?: number;
    /** Video format for example, mp4, hls. */
    format?: string;
    /**
     * Video quality. For example: 480p, 720p.
     * @readonly
     */
    quality?: string | null;
    /**
     * Video filename.
     * @readonly
     */
    filename?: string | null;
    /**
     * Video duration in seconds.
     * @readonly
     */
    durationInSeconds?: number | null;
    /**
     * When true, this is a protected asset, and calling the URL will return a 403 error.
     * In order to access private assets, make a request to:
     * `GenerateFileDownloadUrl` with the WixMedia id and specify the asset_key in the request
     * @readonly
     */
    private?: boolean | null;
    /**
     * Key to identify the video resolution's relationship to the original media in WixMedia.
     * Can be used to request a download for the specific video resolution.
     * For example: 480p.mp4, 720p.mp4, 1080p.mp4, trailer-720p.mp4, clip-720p.mp4
     * @readonly
     */
    assetKey?: string | null;
}
interface ContentAuthor extends ContentAuthorAuthorOneOf {
    /**
     * Wix user ID.
     * @format GUID
     */
    userId?: string | null;
    /**
     * Member ID. See the Members API for more details.
     * @format GUID
     */
    memberId?: string | null;
    /**
     * Visitor ID.
     * @format GUID
     */
    visitorId?: string | null;
    /**
     * Application ID. For more information, see [Authenticate as an App Instance](https://dev.wix.com/docs/build-apps/develop-your-app/access/authentication/authenticate-as-an-app-instance).
     * @format GUID
     */
    appId?: string | null;
}
/** @oneof */
interface ContentAuthorAuthorOneOf {
    /**
     * Wix user ID.
     * @format GUID
     */
    userId?: string | null;
    /**
     * Member ID. See the Members API for more details.
     * @format GUID
     */
    memberId?: string | null;
    /**
     * Visitor ID.
     * @format GUID
     */
    visitorId?: string | null;
    /**
     * Application ID. For more information, see [Authenticate as an App Instance](https://dev.wix.com/docs/build-apps/develop-your-app/access/authentication/authenticate-as-an-app-instance).
     * @format GUID
     */
    appId?: string | null;
}
interface CommentAuthor extends CommentAuthorIdentityOneOf {
    /**
     * Wix user ID.
     * @format GUID
     */
    userId?: string | null;
    /**
     * Member ID. See the Members API for more details.
     * @format GUID
     */
    memberId?: string | null;
    /**
     * Visitor ID.
     * @format GUID
     */
    visitorId?: string | null;
}
/** @oneof */
interface CommentAuthorIdentityOneOf {
    /**
     * Wix user ID.
     * @format GUID
     */
    userId?: string | null;
    /**
     * Member ID. See the Members API for more details.
     * @format GUID
     */
    memberId?: string | null;
    /**
     * Visitor ID.
     * @format GUID
     */
    visitorId?: string | null;
}
interface ParentComment {
    /**
     * Comment ID of the parent comment.
     * @format GUID
     * @immutable
     */
    _id?: string | null;
    /**
     * Author of the parent comment.
     * @readonly
     */
    author?: CommentAuthor;
    /**
     * Parent comment status.
     * @readonly
     */
    status?: StatusWithLiterals;
}
declare enum Status {
    /** Unknown status. */
    UNKNOWN = "UNKNOWN",
    /** This comment is published and publicly visible. */
    PUBLISHED = "PUBLISHED",
    /** This comment is deleted. */
    DELETED = "DELETED",
    /** This comment is pending moderation. Moderation is not currently supported. */
    PENDING = "PENDING",
    /** This comment has been hidden by a site moderator. */
    HIDDEN = "HIDDEN"
}
/** @enumType */
type StatusWithLiterals = Status | 'UNKNOWN' | 'PUBLISHED' | 'DELETED' | 'PENDING' | 'HIDDEN';
interface VoteSummary {
    /** Number of upvotes less downvotes on this comment. */
    netVoteCount?: number;
    /** Number of upvotes on this comment. */
    upvoteCount?: number;
    /** Number of downvotes on this comment. */
    downvoteCount?: number;
}
interface CommentReactionSummary {
    /** Total amount of reactions. */
    total?: number;
    /**
     * Number of each type of reaction. `key` is the code for a reaction type and
     * `value` is the amount of that reaction type.
     */
    reactionCodeCount?: Record<string, number>;
}
interface UpdateInternalDocumentsEvent extends UpdateInternalDocumentsEventOperationOneOf {
    /** insert/update documents */
    update?: InternalDocumentUpdateOperation;
    /** delete by document ids */
    deleteByIds?: DeleteByIdsOperation;
    /** delete documents matching filter */
    deleteByFilter?: DeleteByFilterOperation;
    /** update internal documents matching filter */
    updateByFilter?: InternalDocumentUpdateByFilterOperation;
    /** update only existing documents */
    updateExisting?: InternalUpdateExistingOperation;
    /** insert/update documents with versioning */
    versionedUpdate?: VersionedDocumentUpdateOperation;
    /** delete by document ids with versioning */
    versionedDeleteByIds?: VersionedDeleteByIdsOperation;
    /**
     * type of the documents
     * @minLength 2
     */
    documentType?: string;
    /**
     * language of the documents (mandatory)
     * @minLength 2
     */
    language?: string | null;
    /**
     * one or more search documents
     * @deprecated
     */
    addDocuments?: InternalDocument[];
    /**
     * one or more ids of indexed documents to be removed. Removal will happen before addition (if both provided)
     * @deprecated
     */
    removeDocumentIds?: string[];
    /** id to pass to processing notification */
    correlationId?: string | null;
    /** when event was created / issued */
    issuedAt?: Date | null;
}
/** @oneof */
interface UpdateInternalDocumentsEventOperationOneOf {
    /** insert/update documents */
    update?: InternalDocumentUpdateOperation;
    /** delete by document ids */
    deleteByIds?: DeleteByIdsOperation;
    /** delete documents matching filter */
    deleteByFilter?: DeleteByFilterOperation;
    /** update internal documents matching filter */
    updateByFilter?: InternalDocumentUpdateByFilterOperation;
    /** update only existing documents */
    updateExisting?: InternalUpdateExistingOperation;
    /** insert/update documents with versioning */
    versionedUpdate?: VersionedDocumentUpdateOperation;
    /** delete by document ids with versioning */
    versionedDeleteByIds?: VersionedDeleteByIdsOperation;
}
interface InternalDocument {
    /** document with mandatory fields (id) and with fields specific to the type of the document */
    document?: Record<string, any> | null;
}
interface InternalDocumentUpdateOperation {
    /** documents to index or update */
    documents?: InternalDocument[];
}
interface DeleteByIdsOperation {
    /** ids of the documents to delete */
    documentIds?: string[];
    /**
     * tenant id for custom tenancy strategy
     * @minLength 2
     * @maxLength 300
     */
    tenantId?: string | null;
}
interface DeleteByFilterOperation {
    /** documents matching this filter wil be deleted. only filterable documents defined in document_type can be used for filtering */
    filter?: Record<string, any> | null;
    /**
     * tenant id for custom tenancy strategy
     * @minLength 2
     * @maxLength 300
     */
    tenantId?: string | null;
}
interface InternalDocumentUpdateByFilterOperation {
    /** documents matching this filter will be updated */
    filter?: Record<string, any> | null;
    /** partial document to apply */
    document?: InternalDocument;
    /**
     * tenant id for custom tenancy strategy
     * @minLength 2
     * @maxLength 300
     */
    tenantId?: string | null;
}
interface InternalUpdateExistingOperation {
    /** documents to update */
    documents?: InternalDocument[];
}
interface VersionedDocumentUpdateOperation {
    /** documents to create or overwrite */
    documents?: InternalDocument[];
    /** versioning mode to use instead of default */
    versioningMode?: VersioningModeWithLiterals;
}
declare enum VersioningMode {
    /** use default versioning mode agreed with search team */
    DEFAULT = "DEFAULT",
    /** execute only if version is greater than existing */
    GREATER_THAN = "GREATER_THAN",
    /** execute only if version is greater or equal to existing */
    GREATER_OR_EQUAL = "GREATER_OR_EQUAL"
}
/** @enumType */
type VersioningModeWithLiterals = VersioningMode | 'DEFAULT' | 'GREATER_THAN' | 'GREATER_OR_EQUAL';
interface VersionedDeleteByIdsOperation {
    /** ids with version of the documents to delete */
    documentIds?: VersionedDocumentId[];
    /**
     * tenant id for custom tenancy strategy
     * @minLength 2
     * @maxLength 300
     */
    tenantId?: string | null;
}
interface VersionedDocumentId {
    /** document id */
    documentId?: string;
    /** document version */
    version?: string;
    /** versioning mode to use instead of default */
    versioningMode?: VersioningModeWithLiterals;
}
interface CommentModerated {
    comment?: Comment;
    moderationAction?: ActionWithLiterals;
}
declare enum Action {
    /** Unknown content. */
    UNKNOWN = "UNKNOWN",
    /** Approve draft content. */
    APPROVE = "APPROVE",
    /** Reject draft content. */
    REJECT = "REJECT"
}
/** @enumType */
type ActionWithLiterals = Action | 'UNKNOWN' | 'APPROVE' | 'REJECT';
interface CreateCommentRequest {
    /** Comment to create. */
    comment?: Comment;
}
interface ContactDetails {
}
interface CreateCommentResponse {
    /** Created comment. */
    comment?: Comment;
}
interface ResourceCommentCountChanged {
    /** ID of the app that the comment is added to. */
    appId?: string;
    /**
     * ID of the specific context the comment is in response to.
     *
     * Within some Wix apps, the `contextId` will be the same as the `resourceId`. For example in Wix Forum, the `forumPostId` is used as both the `contextId` and the `resourceId`.
     */
    contextId?: string;
    /**
     * ID of the specific resource that the comment is in response to.
     *
     * Within some Wix apps, the `resourceId` will be the same as the `contextId`. For example in Wix Forum, the `forumPostId` is used as both the `resourceId` and the `contextId`.
     */
    resourceId?: string;
    /** How many comments are published for the resource. */
    publishedCommentCount?: number;
}
interface GetCommentRequest {
    /**
     * ID of the comment to retrieve.
     * @format GUID
     */
    commentId: string;
}
interface GetCommentResponse {
    /** Retrieved comment. */
    comment?: Comment;
}
/** Comment info to update. */
interface UpdateCommentRequest {
    /** Comment info to update. */
    comment?: Comment;
}
interface UpdateCommentResponse {
    /** Updated comment. */
    comment?: Comment;
}
interface CommentContentChanged {
    /** Comment ID. */
    commentId?: string;
    /** Content before the update. */
    previousContent?: CommentContent;
    /** Content after the update. */
    currentContent?: CommentContent;
}
interface DeleteCommentRequest {
    /**
     * ID of the comment to delete.
     * @format GUID
     */
    commentId: string;
}
interface DeleteCommentResponse {
}
interface CommentDeleted {
    comment?: Comment;
}
interface ModerateDraftContentRequest {
    /**
     * ID of the comment to moderate.
     * @format GUID
     */
    commentId: string;
    /**
     * Revision number, which increments by `1` each time the comment is updated.
     *
     * To prevent conflicting changes, the current `revision` must be passed when updating the comment.
     */
    revision: string | null;
    /** Draft content action. */
    draftContentAction?: ActionWithLiterals;
}
interface ModerateDraftContentResponse {
    /** Moderated comment. */
    comment?: Comment;
}
interface CommentPublished {
    /** Comment info. */
    comment?: Comment;
    /** Whether this is the first comment publish. */
    firstPublish?: boolean;
}
interface CommentHidden {
    comment?: Comment;
}
interface QueryCommentsRequest {
    /**
     * App ID to query comments for.
     * @format GUID
     */
    appId: string;
    /** Query options. */
    query: CursorQuery;
}
interface CursorQuery extends CursorQueryPagingMethodOneOf {
    /**
     * Cursor paging options.
     *
     * Learn more about [cursor paging](https://dev.wix.com/docs/rest/articles/getting-started/api-query-language#cursor-paging).
     */
    cursorPaging?: CursorPaging;
    /**
     * Filter object.
     *
     * Learn more about the [filter section](https://dev.wix.com/docs/rest/articles/getting-started/api-query-language#the-filter-section).
     */
    filter?: Record<string, any> | null;
    /**
     * Sort object.
     *
     * Learn more about the [sort section](https://dev.wix.com/docs/rest/articles/getting-started/api-query-language#the-sort-section).
     * @maxSize 5
     */
    sort?: Sorting[];
}
/** @oneof */
interface CursorQueryPagingMethodOneOf {
    /**
     * Cursor paging options.
     *
     * Learn more about [cursor paging](https://dev.wix.com/docs/rest/articles/getting-started/api-query-language#cursor-paging).
     */
    cursorPaging?: CursorPaging;
}
interface Sorting {
    /**
     * Name of the field to sort by.
     * @maxLength 512
     */
    fieldName?: string;
    /** Sort order. */
    order?: SortOrderWithLiterals;
}
declare enum SortOrder {
    ASC = "ASC",
    DESC = "DESC"
}
/** @enumType */
type SortOrderWithLiterals = SortOrder | 'ASC' | 'DESC';
interface CursorPaging {
    /**
     * Maximum number of items to return in the results.
     * @max 100
     */
    limit?: number | null;
    /**
     * Pointer to the next or previous page in the list of results.
     *
     * Pass the relevant cursor token from the `pagingMetadata` object in the previous call's response.
     * Not relevant for the first request.
     * @maxLength 16000
     */
    cursor?: string | null;
}
interface QueryCommentsResponse {
    /** Retrieved comments. */
    comments?: Comment[];
    /** Paging metadata. */
    pagingMetadata?: CursorPagingMetadata;
}
interface CursorPagingMetadata {
    /** Number of items returned in current page. */
    count?: number | null;
    /** Cursor strings that point to the next page, previous page, or both. */
    cursors?: Cursors;
    /**
     * Whether there are more pages to retrieve following the current page.
     *
     * + `true`: Another page of results can be retrieved.
     * + `false`: This is the last page.
     */
    hasNext?: boolean | null;
}
interface Cursors {
    /**
     * Cursor string pointing to the next page in the list of results.
     * @maxLength 16000
     */
    next?: string | null;
    /**
     * Cursor pointing to the previous page in the list of results.
     * @maxLength 16000
     */
    prev?: string | null;
}
interface MarkCommentRequest {
    /**
     * ID of the comment to mark.
     * @format GUID
     */
    commentId: string;
}
interface MarkCommentResponse {
    /** Marked comment. */
    comment?: Comment;
}
interface CommentMarked {
    comment?: Comment;
}
interface UnmarkCommentRequest {
    /**
     * ID of the comment to unmark.
     * @format GUID
     */
    commentId: string;
}
interface UnmarkCommentResponse {
    /** Unmarked comment. */
    comment?: Comment;
}
interface CommentUnmarked {
    comment?: Comment;
}
interface HideCommentRequest {
    /**
     * ID of the comment to hide.
     * @format GUID
     */
    commentId: string;
}
interface HideCommentResponse {
    /** Hidden comment. */
    comment?: Comment;
}
interface PublishCommentRequest {
    /**
     * ID of the comment to publish.
     * @format GUID
     */
    commentId: string;
}
interface PublishCommentResponse {
    /** Published comment. */
    comment?: Comment;
}
/** Count comments options. */
interface CountCommentsRequest {
    /**
     * App ID to count the comments of.
     * @format GUID
     */
    appId?: string;
    /** Filter to identify the comments that need to be counted. */
    filter?: Record<string, any> | null;
}
interface CountCommentsResponse {
    /** Number of comments. */
    count?: number;
}
interface ListCommentsByResourceRequest {
    /**
     * ID of the app from which the comments are listed.
     * @format GUID
     */
    appId: string;
    /**
     * ID of the specific context the comment is in response to.
     *
     * Within some Wix apps, the `contextId` will be the same as the `resourceId`. For example in Wix Forum, the `forumPostId` is used as both the `contextId` and the `resourceId`.
     * @maxLength 128
     */
    contextId: string;
    /**
     * Reserved for internal use.
     * @maxLength 128
     */
    contextType?: string;
    /**
     * ID of the specific resource that the comment is in response to.
     *
     * Within some Wix apps, the `resourceId` will be the same as the `contextId`. For example in Wix Forum, the `forumPostId` is used as both the `resourceId` and the `contextId`.
     * @maxLength 128
     */
    resourceId: string;
    /** Comment sort. Is ignored if `cursorPaging.cursor` is defined. */
    commentSort?: CommentSort;
    /** Reply sort. Is ignored if `cursorPaging.cursor` is defined. */
    replySort?: ReplySort;
    /** Cursor paging. */
    cursorPaging?: ListCommentsByResourceCursorPaging;
}
interface CommentSort {
    /** Sort order. */
    order?: OrderWithLiterals;
    /**
     * If set to `true`, marked comments appear in the original order, and not at the top of the list.
     *
     * Default: `false`. This means that marked comments are prioritized and listed first.
     */
    keepMarkedInOriginalOrder?: boolean;
}
declare enum Order {
    /** Unknown order. */
    UNKNOWN_ORDER = "UNKNOWN_ORDER",
    /** Oldest comments appear at the top of the list. */
    OLDEST_FIRST = "OLDEST_FIRST",
    /** Newest comments appear at the top of the list. */
    NEWEST_FIRST = "NEWEST_FIRST",
    /** Comments with the highest reaction count appear at the top of the list. */
    REACTION_COUNT = "REACTION_COUNT",
    /** Comments with the highest vote count appear at the top of the list. */
    NET_VOTE_COUNT = "NET_VOTE_COUNT",
    /** Comments with the highest rating appear at the top of the list. */
    RATING = "RATING",
    /** Comments with the lowest vote count appear at the top of the list. */
    NET_VOTE_COUNT_ASC = "NET_VOTE_COUNT_ASC",
    /** Comments with the lowest rating appear at the top of the list. */
    RATING_ASC = "RATING_ASC"
}
/** @enumType */
type OrderWithLiterals = Order | 'UNKNOWN_ORDER' | 'OLDEST_FIRST' | 'NEWEST_FIRST' | 'REACTION_COUNT' | 'NET_VOTE_COUNT' | 'RATING' | 'NET_VOTE_COUNT_ASC' | 'RATING_ASC';
interface ReplySort {
    /** Sort order. */
    order?: ReplySortOrderWithLiterals;
    /**
     * Whether the marked comments are listed in the original order.
     *
     * If set to `true`, marked comments appear in the original order, and not at the top of the list.
     *
     * Default: `false`. In this case marked comments are prioritized and listed first.
     */
    keepMarkedInOriginalOrder?: boolean;
}
declare enum ReplySortOrder {
    /** Unknown order. */
    UNKNOWN_ORDER = "UNKNOWN_ORDER",
    /** Oldest comments appear at the top of the list. */
    OLDEST_FIRST = "OLDEST_FIRST",
    /** Newest comments appear at the top of the list. */
    NEWEST_FIRST = "NEWEST_FIRST",
    /** Comments with the highest reaction count appear at the top of the list. */
    REACTION_COUNT = "REACTION_COUNT"
}
/** @enumType */
type ReplySortOrderWithLiterals = ReplySortOrder | 'UNKNOWN_ORDER' | 'OLDEST_FIRST' | 'NEWEST_FIRST' | 'REACTION_COUNT';
interface ListCommentsByResourceCursorPaging {
    /** Pointer to the next or previous page in the list of results. */
    cursor?: string | null;
    /**
     * Number of items to return.
     * @min 1
     * @max 100
     */
    limit?: number | null;
    /**
     * Maximum number of replies in a response. Only applicable to parent comments.
     * @max 100
     */
    repliesLimit?: number | null;
}
interface ListCommentsByResourceResponse {
    /** Listed comments. */
    comments?: Comment[];
    /** Paging metadata. */
    pagingMetadata?: CursorPagingMetadata;
    /** Listed comment replies. */
    commentReplies?: Record<string, RepliesListResponse>;
}
interface RepliesListResponse {
    /** Listed comment replies. */
    replies?: Comment[];
    /** Paging metadata. */
    pagingMetadata?: CursorPagingMetadata;
}
interface GetCommentThreadRequest {
    /**
     * App ID.
     * @maxLength 128
     * @deprecated App ID.
     * @targetRemovalDate 2024-11-01
     */
    appId?: string;
    /**
     * Comment ID.
     * @format GUID
     */
    commentId: string;
    /** Comment sorting. */
    commentSort?: CommentSort;
    /** Reply sorting. */
    replySort?: ReplySort;
}
interface GetCommentThreadResponse {
    /** Retrieved replies. */
    comments?: Comment[];
    /** Paging metadata. */
    pagingMetadata?: CursorPagingMetadata;
    /** Retrieved replies of a reply. */
    commentReplies?: Record<string, RepliesListResponse>;
}
interface BulkPublishCommentRequest {
    /**
     * ID of the app where to publish the comment.
     * @format GUID
     */
    appId: string;
    /** Filter to identify the comments that need to be published. Each key corresponds to an option name, and its values correspond to the choices for this option. For example, {`"resourceId"`: `"64ad407e0bf87891bba7de3a"`, `"parentComment.id"`: `"726cb137-a9c3-408b-9cc2-2b64c6be8a95"`}. */
    filter: Record<string, any> | null;
}
interface BulkPublishCommentResponse {
    /**
     * Job ID.
     *
     * Pass this ID to Get Async Job to retrieve job details and metadata.
     * @format GUID
     */
    jobId?: string;
}
interface BulkHideCommentRequest {
    /**
     * ID of the app where to hide the comments.
     * @format GUID
     */
    appId: string;
    /** Filter to identify the comments that need to be hidden. Each key corresponds to an option name, and its values correspond to the choices for this option. For example, {`"resourceId"`: `"64ad407e0bf87891bba7de3a"`, `"parentComment.id"`: `"726cb137-a9c3-408b-9cc2-2b64c6be8a95"`}. */
    filter: Record<string, any> | null;
}
interface BulkHideCommentResponse {
    /**
     * Job ID.
     *
     * Pass this ID to Get Async Job to retrieve job details and metadata.
     * @format GUID
     */
    jobId?: string;
}
interface BulkDeleteCommentRequest {
    /**
     * ID of the app where to delete the comments.
     * @format GUID
     */
    appId: string;
    /** Filter to identify the comments that need to be deleted. Each key corresponds to an option name, and its values correspond to the choices for this option. For example, {`"resourceId"`: `"64ad407e0bf87891bba7de3a"`, `"parentComment.id"`: `"726cb137-a9c3-408b-9cc2-2b64c6be8a95"`}. */
    filter: Record<string, any> | null;
}
interface BulkDeleteCommentResponse {
    /**
     * Job ID.
     *
     * Pass this ID to Get Async Job to retrieve job details and metadata.
     * @format GUID
     */
    jobId?: string;
}
interface BulkModerateDraftContentRequest {
    /**
     * ID of the app where to moderate the comments.
     * @format GUID
     */
    appId: string;
    /** Filter to identify the comment content that needs to be moderated. Each key corresponds to an option name, and its values correspond to the choices for this option. For example, {`"resourceId"`: `"64ad407e0bf87891bba7de3a"`, `"parentComment.id"`: `"726cb137-a9c3-408b-9cc2-2b64c6be8a95"`}. */
    filter: Record<string, any> | null;
    /** Action to do regarding draft content */
    draftContentAction: ActionWithLiterals;
}
interface BulkModerateDraftContentResponse {
    /**
     * Job ID.
     *
     * Pass this ID to Get Async Job to retrieve job details and metadata.
     * @format GUID
     */
    jobId?: string;
}
interface BulkMoveCommentByFilterRequest {
    /**
     * ID of the app from which to move the comments.
     * @format GUID
     */
    appId: string;
    /** Filter to identify the comments that need to be moved. Each key corresponds to an option name, and its values correspond to the choices for this option. For example, {`"resourceId"`: `"64ad407e0bf87891bba7de3a"`, `"parentComment.id"`: `"726cb137-a9c3-408b-9cc2-2b64c6be8a95"`}. */
    filter: Record<string, any> | null;
    /** Where to move the comment. */
    destination?: Destination;
}
interface Destination {
    /**
     * Context ID of where to move the comment to.
     * @maxLength 128
     */
    contextId?: string;
    /**
     * Resource ID of where to move the comment to.
     * @maxLength 128
     */
    resourceId?: string;
}
interface BulkMoveCommentByFilterResponse {
    /**
     * Job ID.
     *
     * Pass this ID to Get Async Job to retrieve job details and metadata.
     * @format GUID
     */
    jobId?: string;
}
interface CommentMoved {
    comment?: Comment;
    destination?: Destination;
}
interface DomainEvent extends DomainEventBodyOneOf {
    createdEvent?: EntityCreatedEvent;
    updatedEvent?: EntityUpdatedEvent;
    deletedEvent?: EntityDeletedEvent;
    actionEvent?: ActionEvent;
    /** Event ID. With this ID you can easily spot duplicated events and ignore them. */
    _id?: string;
    /**
     * Fully Qualified Domain Name of an entity. This is a unique identifier assigned to the API main business entities.
     * For example, `wix.stores.catalog.product`, `wix.bookings.session`, `wix.payments.transaction`.
     */
    entityFqdn?: string;
    /**
     * Event action name, placed at the top level to make it easier for users to dispatch messages.
     * For example: `created`/`updated`/`deleted`/`started`/`completed`/`email_opened`.
     */
    slug?: string;
    /** ID of the entity associated with the event. */
    entityId?: string;
    /** Event timestamp in [ISO-8601](https://en.wikipedia.org/wiki/ISO_8601) format and UTC time. For example, `2020-04-26T13:57:50.699Z`. */
    eventTime?: Date | null;
    /**
     * Whether the event was triggered as a result of a privacy regulation application
     * (for example, GDPR).
     */
    triggeredByAnonymizeRequest?: boolean | null;
    /** If present, indicates the action that triggered the event. */
    originatedFrom?: string | null;
    /**
     * A sequence number that indicates the order of updates to an entity. For example, if an entity was updated at 16:00 and then again at 16:01, the second update will always have a higher sequence number.
     * You can use this number to make sure you're handling updates in the right order. Just save the latest sequence number on your end and compare it to the one in each new message. If the new message has an older (lower) number, you can safely ignore it.
     */
    entityEventSequence?: string | null;
}
/** @oneof */
interface DomainEventBodyOneOf {
    createdEvent?: EntityCreatedEvent;
    updatedEvent?: EntityUpdatedEvent;
    deletedEvent?: EntityDeletedEvent;
    actionEvent?: ActionEvent;
}
interface EntityCreatedEvent {
    entity?: string;
}
interface RestoreInfo {
    deletedDate?: Date | null;
}
interface EntityUpdatedEvent {
    /**
     * Since platformized APIs only expose PATCH and not PUT we can't assume that the fields sent from the client are the actual diff.
     * This means that to generate a list of changed fields (as opposed to sent fields) one needs to traverse both objects.
     * We don't want to impose this on all developers and so we leave this traversal to the notification recipients which need it.
     */
    currentEntity?: string;
}
interface EntityDeletedEvent {
    /** Entity that was deleted. */
    deletedEntity?: string | null;
}
interface ActionEvent {
    body?: string;
}
interface MessageEnvelope {
    /**
     * App instance ID.
     * @format GUID
     */
    instanceId?: string | null;
    /**
     * Event type.
     * @maxLength 150
     */
    eventType?: string;
    /** The identification type and identity data. */
    identity?: IdentificationData;
    /** Stringify payload. */
    data?: string;
}
interface IdentificationData extends IdentificationDataIdOneOf {
    /**
     * ID of a site visitor that has not logged in to the site.
     * @format GUID
     */
    anonymousVisitorId?: string;
    /**
     * ID of a site visitor that has logged in to the site.
     * @format GUID
     */
    memberId?: string;
    /**
     * ID of a Wix user (site owner, contributor, etc.).
     * @format GUID
     */
    wixUserId?: string;
    /**
     * ID of an app.
     * @format GUID
     */
    appId?: string;
    /** @readonly */
    identityType?: WebhookIdentityTypeWithLiterals;
}
/** @oneof */
interface IdentificationDataIdOneOf {
    /**
     * ID of a site visitor that has not logged in to the site.
     * @format GUID
     */
    anonymousVisitorId?: string;
    /**
     * ID of a site visitor that has logged in to the site.
     * @format GUID
     */
    memberId?: string;
    /**
     * ID of a Wix user (site owner, contributor, etc.).
     * @format GUID
     */
    wixUserId?: string;
    /**
     * ID of an app.
     * @format GUID
     */
    appId?: string;
}
declare enum WebhookIdentityType {
    UNKNOWN = "UNKNOWN",
    ANONYMOUS_VISITOR = "ANONYMOUS_VISITOR",
    MEMBER = "MEMBER",
    WIX_USER = "WIX_USER",
    APP = "APP"
}
/** @enumType */
type WebhookIdentityTypeWithLiterals = WebhookIdentityType | 'UNKNOWN' | 'ANONYMOUS_VISITOR' | 'MEMBER' | 'WIX_USER' | 'APP';
interface BaseEventMetadata {
    /**
     * App instance ID.
     * @format GUID
     */
    instanceId?: string | null;
    /**
     * Event type.
     * @maxLength 150
     */
    eventType?: string;
    /** The identification type and identity data. */
    identity?: IdentificationData;
}
interface EventMetadata extends BaseEventMetadata {
    /** Event ID. With this ID you can easily spot duplicated events and ignore them. */
    _id?: string;
    /**
     * Fully Qualified Domain Name of an entity. This is a unique identifier assigned to the API main business entities.
     * For example, `wix.stores.catalog.product`, `wix.bookings.session`, `wix.payments.transaction`.
     */
    entityFqdn?: string;
    /**
     * Event action name, placed at the top level to make it easier for users to dispatch messages.
     * For example: `created`/`updated`/`deleted`/`started`/`completed`/`email_opened`.
     */
    slug?: string;
    /** ID of the entity associated with the event. */
    entityId?: string;
    /** Event timestamp in [ISO-8601](https://en.wikipedia.org/wiki/ISO_8601) format and UTC time. For example, `2020-04-26T13:57:50.699Z`. */
    eventTime?: Date | null;
    /**
     * Whether the event was triggered as a result of a privacy regulation application
     * (for example, GDPR).
     */
    triggeredByAnonymizeRequest?: boolean | null;
    /** If present, indicates the action that triggered the event. */
    originatedFrom?: string | null;
    /**
     * A sequence number that indicates the order of updates to an entity. For example, if an entity was updated at 16:00 and then again at 16:01, the second update will always have a higher sequence number.
     * You can use this number to make sure you're handling updates in the right order. Just save the latest sequence number on your end and compare it to the one in each new message. If the new message has an older (lower) number, you can safely ignore it.
     */
    entityEventSequence?: string | null;
}
interface CommentContentChangedEnvelope {
    data: CommentContentChanged;
    metadata: EventMetadata;
}
interface CommentHiddenEnvelope {
    data: CommentHidden;
    metadata: EventMetadata;
}
interface CommentMarkedEnvelope {
    data: CommentMarked;
    metadata: EventMetadata;
}
interface CommentMovedEnvelope {
    data: CommentMoved;
    metadata: EventMetadata;
}
interface CommentPublishedEnvelope {
    data: CommentPublished;
    metadata: EventMetadata;
}
interface CommentUnmarkedEnvelope {
    data: CommentUnmarked;
    metadata: EventMetadata;
}
interface CommentCreatedEnvelope {
    entity: Comment;
    metadata: EventMetadata;
}
interface CommentResourceCommentCountChangedEnvelope {
    data: ResourceCommentCountChanged;
    metadata: EventMetadata;
}
interface CommentUpdatedEnvelope {
    entity: Comment;
    metadata: EventMetadata;
}
interface UpdateComment {
    /**
     * Comment ID.
     * @format GUID
     * @readonly
     */
    _id?: string | null;
    /**
     * Revision number, which increments by 1 each time the comment is updated.
     *
     * To prevent conflicting changes, the current `revision` must be passed when updating the comment.
     * @readonly
     */
    revision?: string | null;
    /**
     * Date and time the comment was created.
     *
     * **Note:** This is the date from the system database, not the actual date when the comment was created. For example, if you migrate comments created in 2016, the `createdDate` field will show the current year. For the actual creation date, see the `commentDate` field.
     * @readonly
     */
    _createdDate?: Date | null;
    /**
     * Date and time the comment was last updated.
     * @readonly
     */
    _updatedDate?: Date | null;
    /**
     * ID of the app that the comment is added to.
     * @format GUID
     * @immutable
     */
    appId?: string | null;
    /**
     * ID of the specific context the comment is in response to.
     *
     * Within some Wix apps, the `contextId` will be the same as the `resourceId`. For example in Wix Forum,
     * the `forumPostId` is used as both the `contextId` and the `resourceId`.
     * @immutable
     * @maxLength 128
     */
    contextId?: string | null;
    /**
     * ID of the specific resource that the comment is in response to.
     *
     * Within some Wix apps, the `resourceId` will be the same as the `contextId`. For example in Wix Forum,
     * the `forumPostId` is used as both the `resourceId` and the `contextId`.
     * @immutable
     * @maxLength 128
     */
    resourceId?: string | null;
    /** Published comment content. */
    content?: CommentContent;
    /**
     * Comment's author.
     * @immutable
     */
    author?: CommentAuthor;
    /**
     * Parent comment information.
     *
     * Only present if this comment is in a direct reply to another comment.
     * See **Terminology** in the Comments introduction
     * for more information about parent comments.
     */
    parentComment?: ParentComment;
    /**
     * Number of comments that reply to this comment.
     * @readonly
     */
    replyCount?: number;
    /**
     * Summary of votes.
     * @readonly
     */
    voteSummary?: VoteSummary;
    /**
     * Comment status.
     * @readonly
     */
    status?: StatusWithLiterals;
    /**
     * Comment rating.
     * @readonly
     */
    rating?: number | null;
    /**
     * Summary of reactions.
     * @readonly
     */
    reactionSummary?: CommentReactionSummary;
    /** Whether the comment is marked. */
    marked?: boolean;
    /**
     * Date and time when the comment was actually created.
     * @immutable
     */
    commentDate?: Date | null;
    /**
     * Whether the comment has the updated content.
     * @readonly
     */
    contentEdited?: boolean | null;
}
interface ModerateDraftContentOptions {
    /** Draft content action. */
    draftContentAction?: ActionWithLiterals;
}
interface QueryCursorResult {
    cursors: Cursors;
    hasNext: () => boolean;
    hasPrev: () => boolean;
    length: number;
    pageSize: number;
}
interface CommentsQueryResult extends QueryCursorResult {
    items: Comment[];
    query: CommentsQueryBuilder;
    next: () => Promise<CommentsQueryResult>;
    prev: () => Promise<CommentsQueryResult>;
}
interface CommentsQueryBuilder {
    /** @param propertyName - Property whose value is compared with `value`.
     * @param value - Value to compare against.
     */
    eq: (propertyName: '_id' | 'contextId' | 'resourceId' | 'author.userId' | 'author.memberId' | 'author.visitorId' | 'parentComment.id' | 'replyCount' | 'voteSummary.netVoteCount' | 'status' | 'rating' | 'reactionSummary.total' | 'marked', value: any) => CommentsQueryBuilder;
    /** @param propertyName - Property whose value is compared with `value`.
     * @param value - Value to compare against.
     */
    ne: (propertyName: '_id' | 'contextId' | 'resourceId' | 'author.userId' | 'author.memberId' | 'author.visitorId' | 'parentComment.id' | 'replyCount' | 'voteSummary.netVoteCount' | 'status' | 'rating' | 'reactionSummary.total' | 'marked', value: any) => CommentsQueryBuilder;
    /** @param propertyName - Property whose value is compared with `value`.
     * @param value - Value to compare against.
     */
    ge: (propertyName: 'replyCount' | 'voteSummary.netVoteCount' | 'rating' | 'reactionSummary.total', value: any) => CommentsQueryBuilder;
    /** @param propertyName - Property whose value is compared with `value`.
     * @param value - Value to compare against.
     */
    gt: (propertyName: 'replyCount' | 'voteSummary.netVoteCount' | 'rating' | 'reactionSummary.total', value: any) => CommentsQueryBuilder;
    /** @param propertyName - Property whose value is compared with `value`.
     * @param value - Value to compare against.
     */
    le: (propertyName: 'replyCount' | 'voteSummary.netVoteCount' | 'rating' | 'reactionSummary.total', value: any) => CommentsQueryBuilder;
    /** @param propertyName - Property whose value is compared with `value`.
     * @param value - Value to compare against.
     */
    lt: (propertyName: 'replyCount' | 'voteSummary.netVoteCount' | 'rating' | 'reactionSummary.total', value: any) => CommentsQueryBuilder;
    /** @param propertyName - Property whose value is compared with `values`.
     * @param values - List of values to compare against.
     */
    hasSome: (propertyName: string, value: any[]) => CommentsQueryBuilder;
    /** @param propertyName - Property whose value is compared with `values`.
     * @param values - List of values to compare against.
     */
    hasAll: (propertyName: string, value: any[]) => CommentsQueryBuilder;
    in: (propertyName: '_id' | 'contextId' | 'resourceId' | 'author.userId' | 'author.memberId' | 'author.visitorId' | 'parentComment.id' | 'status', value: any) => CommentsQueryBuilder;
    /** @param propertyNames - Properties used in the sort. To sort by multiple properties, pass properties as additional arguments. */
    ascending: (...propertyNames: Array<'replyCount' | 'voteSummary.netVoteCount' | 'rating' | 'reactionSummary.total' | 'marked'>) => CommentsQueryBuilder;
    /** @param propertyNames - Properties used in the sort. To sort by multiple properties, pass properties as additional arguments. */
    descending: (...propertyNames: Array<'replyCount' | 'voteSummary.netVoteCount' | 'rating' | 'reactionSummary.total' | 'marked'>) => CommentsQueryBuilder;
    /** @param limit - Number of items to return, which is also the `pageSize` of the results object. */
    limit: (limit: number) => CommentsQueryBuilder;
    /** @param cursor - A pointer to specific record */
    skipTo: (cursor: string) => CommentsQueryBuilder;
    find: () => Promise<CommentsQueryResult>;
}
interface CountCommentsOptions {
    /** Filter to identify the comments that need to be counted. */
    filter?: Record<string, any> | null;
}
interface ListCommentsByResourceOptions {
    /**
     * ID of the specific context the comment is in response to.
     *
     * Within some Wix apps, the `contextId` will be the same as the `resourceId`. For example in Wix Forum, the `forumPostId` is used as both the `contextId` and the `resourceId`.
     * @maxLength 128
     */
    contextId: string;
    /**
     * Reserved for internal use.
     * @maxLength 128
     */
    contextType?: string;
    /**
     * ID of the specific resource that the comment is in response to.
     *
     * Within some Wix apps, the `resourceId` will be the same as the `contextId`. For example in Wix Forum, the `forumPostId` is used as both the `resourceId` and the `contextId`.
     * @maxLength 128
     */
    resourceId: string;
    /** Comment sort. Is ignored if `cursorPaging.cursor` is defined. */
    commentSort?: CommentSort;
    /** Reply sort. Is ignored if `cursorPaging.cursor` is defined. */
    replySort?: ReplySort;
    /** Cursor paging. */
    cursorPaging?: ListCommentsByResourceCursorPaging;
}
interface GetCommentThreadOptions {
    /**
     * App ID.
     * @maxLength 128
     * @deprecated App ID.
     * @targetRemovalDate 2024-11-01
     */
    appId?: string;
    /** Comment sorting. */
    commentSort?: CommentSort;
    /** Reply sorting. */
    replySort?: ReplySort;
}
interface BulkPublishCommentOptions {
    /** Filter to identify the comments that need to be published. Each key corresponds to an option name, and its values correspond to the choices for this option. For example, {`"resourceId"`: `"64ad407e0bf87891bba7de3a"`, `"parentComment.id"`: `"726cb137-a9c3-408b-9cc2-2b64c6be8a95"`}. */
    filter: Record<string, any> | null;
}
interface BulkHideCommentOptions {
    /** Filter to identify the comments that need to be hidden. Each key corresponds to an option name, and its values correspond to the choices for this option. For example, {`"resourceId"`: `"64ad407e0bf87891bba7de3a"`, `"parentComment.id"`: `"726cb137-a9c3-408b-9cc2-2b64c6be8a95"`}. */
    filter: Record<string, any> | null;
}
interface BulkDeleteCommentOptions {
    /** Filter to identify the comments that need to be deleted. Each key corresponds to an option name, and its values correspond to the choices for this option. For example, {`"resourceId"`: `"64ad407e0bf87891bba7de3a"`, `"parentComment.id"`: `"726cb137-a9c3-408b-9cc2-2b64c6be8a95"`}. */
    filter: Record<string, any> | null;
}
interface BulkModerateDraftContentOptions {
    /** Filter to identify the comment content that needs to be moderated. Each key corresponds to an option name, and its values correspond to the choices for this option. For example, {`"resourceId"`: `"64ad407e0bf87891bba7de3a"`, `"parentComment.id"`: `"726cb137-a9c3-408b-9cc2-2b64c6be8a95"`}. */
    filter: Record<string, any> | null;
    /** Action to do regarding draft content */
    draftContentAction: ActionWithLiterals;
}
interface BulkMoveCommentByFilterOptions {
    /** Filter to identify the comments that need to be moved. Each key corresponds to an option name, and its values correspond to the choices for this option. For example, {`"resourceId"`: `"64ad407e0bf87891bba7de3a"`, `"parentComment.id"`: `"726cb137-a9c3-408b-9cc2-2b64c6be8a95"`}. */
    filter: Record<string, any> | null;
    /** Where to move the comment. */
    destination?: Destination;
}

export { VoteRole as $, PluginContainerDataAlignment as A, type BulkPublishCommentOptions as B, type Comment as C, Target as D, TextAlignment as E, LineStyle as F, type GetCommentThreadOptions as G, type HideCommentResponse as H, Width as I, Alignment as J, LayoutType as K, type ListCommentsByResourceOptions as L, type ModerateDraftContentOptions as M, NodeType as N, Orientation as O, type PublishCommentResponse as P, Crop as Q, ThumbnailsAlignment as R, GIFType as S, Type as T, type UpdateComment as U, ViewMode as V, WidthType as W, Source as X, Position as Y, MapType as Z, ViewRole as _, type ModerateDraftContentResponse as a, type ParagraphData as a$, PollLayoutType as a0, PollLayoutDirection as a1, BackgroundType as a2, DecorationType as a3, FontType as a4, AppType as a5, InitialExpandedItems as a6, Direction as a7, VerticalAlignment as a8, NullValue as a9, type DividerData as aA, type FileData as aB, type FileSource as aC, type FileSourceDataOneOf as aD, type PDFSettings as aE, type GalleryData as aF, type Media as aG, type Image as aH, type Video as aI, type Item as aJ, type ItemDataOneOf as aK, type GalleryOptions as aL, type Layout as aM, type ItemStyle as aN, type Thumbnails as aO, type GIFData as aP, type GIF as aQ, type HeadingData as aR, type HTMLData as aS, type HTMLDataDataOneOf as aT, type ImageData as aU, type StylesBorder as aV, type ImageDataStyles as aW, type LinkPreviewData as aX, type LinkPreviewDataStyles as aY, type MapData as aZ, type MapSettings as a_, Status as aa, VersioningMode as ab, Action as ac, SortOrder as ad, Order as ae, ReplySortOrder as af, WebhookIdentityType as ag, type CommentContent as ah, type RichContent as ai, type Node as aj, type NodeDataOneOf as ak, type NodeStyle as al, type ButtonData as am, type Border as an, type Colors as ao, type PluginContainerData as ap, type PluginContainerDataWidth as aq, type PluginContainerDataWidthDataOneOf as ar, type Spoiler as as, type Height as at, type Styles as au, type Link as av, type LinkDataOneOf as aw, type Rel as ax, type CodeBlockData as ay, type TextStyle as az, type CommentsQueryBuilder as b, type DeleteByIdsOperation as b$, type PollData as b0, type Permissions as b1, type Option as b2, type Settings as b3, type PollLayout as b4, type OptionLayout as b5, type Gradient as b6, type Background as b7, type BackgroundBackgroundOneOf as b8, type PollDesign as b9, type BorderColors as bA, type ListValue as bB, type AudioData as bC, type OrderedListData as bD, type BulletedListData as bE, type BlockquoteData as bF, type CaptionData as bG, type LayoutCellData as bH, type Metadata as bI, type DocumentStyle as bJ, type TextNodeStyle as bK, type Mention as bL, type MentionIdentityOneOf as bM, type Attachment as bN, type AttachmentMediaOneOf as bO, type VideoResolution as bP, type ContentAuthor as bQ, type ContentAuthorAuthorOneOf as bR, type CommentAuthor as bS, type CommentAuthorIdentityOneOf as bT, type ParentComment as bU, type VoteSummary as bV, type CommentReactionSummary as bW, type UpdateInternalDocumentsEvent as bX, type UpdateInternalDocumentsEventOperationOneOf as bY, type InternalDocument as bZ, type InternalDocumentUpdateOperation as b_, type OptionDesign as ba, type Poll as bb, type PollDataLayout as bc, type Design as bd, type TextData as be, type Decoration as bf, type DecorationDataOneOf as bg, type AnchorData as bh, type ColorData as bi, type LinkData as bj, type MentionData as bk, type FontSizeData as bl, type SpoilerData as bm, type AppEmbedData as bn, type AppEmbedDataAppDataOneOf as bo, type BookingData as bp, type EventData as bq, type VideoData as br, type PlaybackOptions as bs, type EmbedData as bt, type Oembed as bu, type CollapsibleListData as bv, type TableData as bw, type Dimensions as bx, type TableCellData as by, type CellStyle as bz, type MarkCommentResponse as c, type DeleteByFilterOperation as c0, type InternalDocumentUpdateByFilterOperation as c1, type InternalUpdateExistingOperation as c2, type VersionedDocumentUpdateOperation as c3, type VersionedDeleteByIdsOperation as c4, type VersionedDocumentId as c5, type CommentModerated as c6, type CreateCommentRequest as c7, type ContactDetails as c8, type CreateCommentResponse as c9, type CountCommentsRequest as cA, type ListCommentsByResourceRequest as cB, type CommentSort as cC, type ReplySort as cD, type ListCommentsByResourceCursorPaging as cE, type RepliesListResponse as cF, type GetCommentThreadRequest as cG, type BulkPublishCommentRequest as cH, type BulkHideCommentRequest as cI, type BulkDeleteCommentRequest as cJ, type BulkModerateDraftContentRequest as cK, type BulkMoveCommentByFilterRequest as cL, type Destination as cM, type CommentMoved as cN, type DomainEvent as cO, type DomainEventBodyOneOf as cP, type EntityCreatedEvent as cQ, type RestoreInfo as cR, type EntityUpdatedEvent as cS, type EntityDeletedEvent as cT, type ActionEvent as cU, type MessageEnvelope as cV, type IdentificationData as cW, type IdentificationDataIdOneOf as cX, type BaseEventMetadata as cY, type EventMetadata as cZ, type CommentsQueryResult as c_, type ResourceCommentCountChanged as ca, type GetCommentRequest as cb, type GetCommentResponse as cc, type UpdateCommentRequest as cd, type UpdateCommentResponse as ce, type CommentContentChanged as cf, type DeleteCommentRequest as cg, type DeleteCommentResponse as ch, type CommentDeleted as ci, type ModerateDraftContentRequest as cj, type CommentPublished as ck, type CommentHidden as cl, type QueryCommentsRequest as cm, type CursorQuery as cn, type CursorQueryPagingMethodOneOf as co, type Sorting as cp, type CursorPaging as cq, type QueryCommentsResponse as cr, type CursorPagingMetadata as cs, type Cursors as ct, type MarkCommentRequest as cu, type CommentMarked as cv, type UnmarkCommentRequest as cw, type CommentUnmarked as cx, type HideCommentRequest as cy, type PublishCommentRequest as cz, type UnmarkCommentResponse as d, type CountCommentsOptions as e, type CountCommentsResponse as f, type ListCommentsByResourceResponse as g, type GetCommentThreadResponse as h, type BulkPublishCommentResponse as i, type BulkHideCommentOptions as j, type BulkHideCommentResponse as k, type BulkDeleteCommentOptions as l, type BulkDeleteCommentResponse as m, type BulkModerateDraftContentOptions as n, type BulkModerateDraftContentResponse as o, type BulkMoveCommentByFilterOptions as p, type BulkMoveCommentByFilterResponse as q, type CommentContentChangedEnvelope as r, type CommentHiddenEnvelope as s, type CommentMarkedEnvelope as t, type CommentMovedEnvelope as u, type CommentPublishedEnvelope as v, type CommentUnmarkedEnvelope as w, type CommentCreatedEnvelope as x, type CommentResourceCommentCountChangedEnvelope as y, type CommentUpdatedEnvelope as z };
